@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -37,7 +37,7 @@ command  = "GNOME"
 
 password = getpass.getpass()
 
-cli = x2go.X2goClient(use_cache=False, loglevel=x2go.log.loglevel_DEBUG)
+cli = x2go.X2GoClient(use_cache=False, loglevel=x2go.log.loglevel_DEBUG)
 s_uuid = cli.register_session(server, port=port,
                               username=username,
                               cmd=command,
