@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -26,6 +26,11 @@ Introduction
     With Python X2Go you can write your own X2Go clients or embed X2Go client
     features into already existing application environments.
 
+    NOTE: Beginning with v0.4.0.0 of Python X2Go all class names start with
+    X2Go***. Earlier versions used X2go***. As X2Go is the official name of the
+    project (i.e. with a capital X and a capital G) we have adapted the class
+    names to this circumstance.
+
 API Concept
 ===========
 
@@ -38,25 +43,25 @@ API Concept
 
     Python X2Go only offers five public API classes. With the release of
     version 0.1.0.0, we will try to keep these five public API classes
-    of future releases as compatible as possible with versions of Python X2go
+    of future releases as compatible as possible with versions of Python X2Go
     greater/equal than v0.1.0.0.
 
     The five public API classes are:
 
-        - L{X2goClient} --- a whole X2Go client API
-        - L{X2goSession} --- management of an individual X2Go 
-        session--either started standalone or from within an L{X2goClient} instance
-        - L{X2goClientSettings} --- provide access to X2Go (global and 
+        - L{X2GoClient} --- a whole X2Go client API
+        - L{X2GoSession} --- management of an individual X2Go 
+        session--either started standalone or from within an L{X2GoClient} instance
+        - L{X2GoClientSettings} --- provide access to X2Go (global and 
         user) configuration node »settings«
-        - L{X2goClientPrinting} --- provide access to X2Go (global and 
+        - L{X2GoClientPrinting} --- provide access to X2Go (global and 
         user) configuration node »printing«
-        - L{X2goSessionProfiles} --- provide access to X2Go (global and 
+        - L{X2GoSessionProfiles} --- provide access to X2Go (global and 
         user) configuration node »sessions«
 
     Plus two extra classes on MS Windows platforms:
 
-       - L{X2goClientXConfig} and L{X2goXServer} --- these classes will be initialized 
-       during L{X2goClient} instantiation on MS Windows platforms and start an installed XServer
+       - L{X2GoClientXConfig} and L{X2GoXServer} --- these classes will be initialized 
+       during L{X2GoClient} instantiation on MS Windows platforms and start an installed XServer
 
     Any other of the Python X2Go classes may be subject to internal changes
     and the way of addressing these classes in code may vary between different
@@ -68,40 +73,40 @@ API Structure
 =============
 
     When using Python X2Go in your applications, the basic idea is that you
-    create your own class and inherit the X2goClient class in that::
+    create your own class and inherit the X2GoClient class in that::
 
         import x2go
-        class MyX2goClient(x2go.X2goClient):
+        class MyX2GoClient(x2go.X2GoClient):
 
             ...
 
     Python X2Go is capable of handling multiple running/suspended sessions within the
     same client instance, so for your application, there should not be any need of
-    instantiating more than one L{X2goClient} object in parallel. 
+    instantiating more than one L{X2GoClient} object in parallel. 
 
     NOTE: Doing so is--herewith--fully disrecommended.
 
-    The L{X2goClient} class flattens the complex structure of Python X2Go into
-    many L{X2goClient} methods that you can use in your own C{MyX2goClient} instance.
+    The L{X2GoClient} class flattens the complex structure of Python X2Go into
+    many L{X2GoClient} methods that you can use in your own C{MyX2GoClient} instance.
 
     However, it might be handy to retrieve a whole X2Go session instance 
-    from the L{X2goClient} instance. This can be achieved by the 
-    L{X2goClient.register_session()} method::
+    from the L{X2GoClient} instance. This can be achieved by the 
+    L{X2GoClient.register_session()} method::
 
         import x2go
-        my_x2gocli = MyX2goClient()
+        my_x2gocli = MyX2GoClient()
         reg_session_instance = my_x2gocli.register_session(<options>, return_object=True)
 
     Whereas <options> can be as simple as::
 
          »profile_name=<PROFILE_NAME_IN_SESSIONS_FILE>«
 
-    or contain a whole set of L{X2goSession} parameters that can be used to start a 
+    or contain a whole set of L{X2GoSession} parameters that can be used to start a 
     session manually (i.e. a session that is based on a pre-configured session profile 
     in either of the »sessions« config files).
 
-    The L{X2goClient.register_session()} method---in object-retrieval-mode---returns
-    an L{X2goSession} instance. With this instance you can then manage
+    The L{X2GoClient.register_session()} method---in object-retrieval-mode---returns
+    an L{X2GoSession} instance. With this instance you can then manage
     your X2Go session::
 
         import gevent, getpass
@@ -126,8 +131,8 @@ API Structure
     How to access---especially how to modify---the X2Go client configuration
     files »settings«, »printing«, »sessions« and »xconfig« (Windows only)
     is explained in detail with each class declaration in this API documentation. 
-    Please refer to the class docs of L{X2goClientSettings}, L{X2goClientPrinting},
-    L{X2goSessionProfiles} and L{X2goXServer}.
+    Please refer to the class docs of L{X2GoClientSettings}, L{X2GoClientPrinting},
+    L{X2GoSessionProfiles} and L{X2GoXServer}.
 
 
 Configuration and Session Management
@@ -142,22 +147,22 @@ Configuration and Session Management
     section, a section in the Windows registry, etc.
 
     NOTE: Each configuration node will be re-read whenever it is needed 
-    by an X2Go sesion or the X2goClient class itself.
+    by an X2Go sesion or the X2GoClient class itself.
 
     Conclusively, any change to either of the configuration nodes
     will be reflected as a change in your X2Go client behaviour:
 
-      - L{X2goSessionProfiles}: changes to a session profile in
+      - L{X2GoSessionProfiles}: changes to a session profile in
       the »sessions« node will be available for the next registered
-      L{X2goSession} instance
-      - L{X2goClientPrinting}: on each incoming X2Go print job the
+      L{X2GoSession} instance
+      - L{X2GoClientPrinting}: on each incoming X2Go print job the
       »printing« configuration node will be re-read, thus you can 
       change your X2Go client's print setup during a running session
-      - L{X2goClientSettings}: also the configuration node »settings« 
+      - L{X2GoClientSettings}: also the configuration node »settings« 
       is re-read whenever needed in the course of X2Go session management
-      - L{X2goClientXConfig} and L{X2goXServer} (Windows only): these classes will only be initialized 
+      - L{X2GoClientXConfig} and L{X2GoXServer} (Windows only): these classes will only be initialized 
       once (starting the XServer on Windows platforms) on construction
-      of an L{X2goClient} instance
+      of an L{X2GoClient} instance
 
 Dependencies
 ============
@@ -178,19 +183,19 @@ Contact
 """
 
 __NAME__    = 'python-x2go'
-__VERSION__ = '0.2.1.0'
+__VERSION__ = '0.4.0.5'
 
 from gevent import monkey
 monkey.patch_all()
 
 import utils
 
-from client import X2goClient
-from backends.profiles import X2goSessionProfiles
-from backends.printing import X2goClientPrinting
-from backends.settings import X2goClientSettings
-from session import X2goSession
-from sshproxy import X2goSSHProxy
+from client import X2GoClient
+from backends.profiles import X2GoSessionProfiles
+from backends.printing import X2GoClientPrinting
+from backends.settings import X2GoClientSettings
+from session import X2GoSession
+from sshproxy import X2GoSSHProxy
 from x2go_exceptions import *
 from log import *
 
@@ -204,5 +209,16 @@ from defaults import X2GO_SESSIONS_ROOTDIR
 from defaults import X2GO_SSH_ROOTDIR
 
 if X2GOCLIENT_OS == 'Windows':
-    from xserver import X2goClientXConfig, X2goXServer
+    from xserver import X2GoClientXConfig, X2GoXServer
 
+# compat section
+X2goClient = X2GoClient
+X2goSessionProfiles = X2GoSessionProfiles
+X2goClientPrinting = X2GoClientPrinting
+X2goClientSettings = X2GoClientSettings
+X2goSession = X2GoSession
+X2goSSHProxy = X2GoSSHProxy
+
+if X2GOCLIENT_OS == 'Windows':
+    X2goClientXConfig = X2GoClientXConfig
+    X2goXServer = X2GoXServer
