@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goControlSessionSTDOUT class - core functions for handling your individual X2Go sessions.
+X2GoControlSessionSTDOUT class - core functions for handling your individual X2Go sessions.
 
 This backend handles X2Go server implementations that respond via server-side STDOUT.
 
@@ -48,10 +48,10 @@ import x2go.x2go_exceptions as x2go_exceptions
 import x2go.defaults as defaults
 import x2go.checkhosts as checkhosts
 
-from x2go.backends.terminal import X2goTerminalSession as _X2goTerminalSession
-from x2go.backends.info import X2goServerSessionInfo as _X2goServerSessionInfo
-from x2go.backends.info import X2goServerSessionList as _X2goServerSessionList
-from x2go.backends.proxy import X2goProxy as _X2goProxy
+from x2go.backends.terminal import X2GoTerminalSession as _X2GoTerminalSession
+from x2go.backends.info import X2GoServerSessionInfo as _X2GoServerSessionInfo
+from x2go.backends.info import X2GoServerSessionList as _X2GoServerSessionList
+from x2go.backends.proxy import X2GoProxy as _X2GoProxy
 
 import x2go._paramiko
 x2go._paramiko.monkey_patch_paramiko()
@@ -103,7 +103,7 @@ def _rewrite_password(cmd, user=None, password=None):
     return cmd
 
 
-class X2goControlSessionSTDOUT(paramiko.SSHClient):
+class X2GoControlSessionSTDOUT(paramiko.SSHClient):
     """\
     In the Python X2Go concept, X2Go sessions fall into two parts: a control session and one to many terminal sessions.
 
@@ -118,22 +118,24 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                  add_to_known_hosts=False,
                  known_hosts=None,
                  forward_sshagent=False,
-                 terminal_backend=_X2goTerminalSession,
-                 info_backend=_X2goServerSessionInfo,
-                 list_backend=_X2goServerSessionList,
-                 proxy_backend=_X2goProxy,
+                 unique_hostkey_aliases=False,
+                 terminal_backend=_X2GoTerminalSession,
+                 info_backend=_X2GoServerSessionInfo,
+                 list_backend=_X2GoServerSessionList,
+                 proxy_backend=_X2GoProxy,
                  client_rootdir=os.path.join(defaults.LOCAL_HOME, defaults.X2GO_CLIENT_ROOTDIR),
                  sessions_rootdir=os.path.join(defaults.LOCAL_HOME, defaults.X2GO_SESSIONS_ROOTDIR),
                  ssh_rootdir=os.path.join(defaults.LOCAL_HOME, defaults.X2GO_SSH_ROOTDIR),
                  logger=None, loglevel=log.loglevel_DEFAULT,
                  published_applications_no_submenus=0,
+                 low_latency=False,
                  **kwargs):
         """\
         Initialize an X2Go control session. For each connected session profile there will be one SSH-based
         control session and one to many terminal sessions that all server-client-communicate via this one common control
         session.
 
-        A control session normally gets set up by an L{X2goSession} instance. Do not use it directly!!!
+        A control session normally gets set up by an L{X2GoSession} instance. Do not use it directly!!!
 
         @param profile_name: the profile name of the session profile this control session works for
         @type profile_name: C{str}
@@ -143,14 +145,17 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @type known_hosts: C{str}
         @param forward_sshagent: forward SSH agent authentication requests to the X2Go client-side
         @type forward_sshagent: C{bool}
+        @param unique_hostkey_aliases: instead of storing [<hostname>]:<port> in known_hosts file, use the
+            (unique-by-design) profile ID
+        @type unique_hostkey_aliases: C{bool}
         @param terminal_backend: X2Go terminal session backend to use
         @type terminal_backend: C{class}
         @param info_backend: backend for handling storage of server session information
-        @type info_backend: C{X2goServerSessionInfo*} instance
+        @type info_backend: C{X2GoServerSessionInfo*} instance
         @param list_backend: backend for handling storage of session list information
-        @type list_backend: C{X2goServerSessionList*} instance
+        @type list_backend: C{X2GoServerSessionList*} instance
         @param proxy_backend: backend for handling the X-proxy connections
-        @type proxy_backend: C{X2goProxy*} instance
+        @type proxy_backend: C{X2GoProxy*} instance
         @param client_rootdir: client base dir (default: ~/.x2goclient)
         @type client_rootdir: C{str}
         @param sessions_rootdir: sessions base dir (default: ~/.x2go)
@@ -160,12 +165,14 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @param published_applications_no_submenus: published applications menus with less items than C{published_applications_no_submenus}
             are rendered without submenus
         @type published_applications_no_submenus: C{int}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goControlSessionSTDOUT} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoControlSessionSTDOUT} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
+        @param low_latency: set this boolean switch for weak connections, it will double all timeout values.
+        @type low_latency: C{bool}
         @param kwargs: catch any non-defined parameters in C{kwargs}
         @type kwargs: C{dict}
 
@@ -177,6 +184,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         self.add_to_known_hosts = add_to_known_hosts
         self.known_hosts = known_hosts
         self.forward_sshagent = forward_sshagent
+        self.unique_hostkey_aliases = unique_hostkey_aliases
 
         self.hostname = None
         self.port = None
@@ -189,10 +197,11 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         self._remote_username = None
         self._remote_peername = None
 
+        self._server_versions = None
         self._server_features = None
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -217,6 +226,8 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
 
         self.session_died = False
 
+        self.low_latency = low_latency
+
         self.published_applications_no_submenus = published_applications_no_submenus
         self._already_querying_published_applications = threading.Lock()
 
@@ -271,7 +282,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @param remote_path: full remote path name of the server-side target location, path names have to be Unix-compliant
         @type remote_path: C{str}
 
-        @raise X2goControlSessionException: if the SSH connection dropped out
+        @raise X2GoControlSessionException: if the SSH connection dropped out
 
         """
         ssh_transport = self.get_transport()
@@ -285,7 +296,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 # react to connection dropped error for SSH connections
                 self.session_died = True
                 self._transport_lock.release()
-                raise x2go_exceptions.X2goControlSessionException('The SSH connection was dropped during an sFTP put action.')
+                raise x2go_exceptions.X2GoControlSessionException('The SSH connection was dropped during an sFTP put action.')
             self.sftp_client = None
         self._transport_lock.release()
 
@@ -300,7 +311,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @param content: a text file, multi-line files use Unix-link EOL style
         @type content: C{str}
 
-        @raise X2goControlSessionException: if the SSH connection dropped out
+        @raise X2GoControlSessionException: if the SSH connection dropped out
 
         """
         ssh_transport = self.get_transport()
@@ -317,7 +328,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 self.session_died = True
                 self._transport_lock.release()
                 self.logger('sFTP-write: opening remote file %s on host %s failed' % (remote_path, self.remote_peername()), loglevel=log.loglevel_WARN)
-                raise x2go_exceptions.X2goControlSessionException('The SSH connection was dropped during an sFTP write action.')
+                raise x2go_exceptions.X2GoControlSessionException('The SSH connection was dropped during an sFTP write action.')
             self.sftp_client = None
         self._transport_lock.release()
 
@@ -330,7 +341,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @param remote_path: full remote path name of the server-side file to be removed, path names have to be Unix-compliant
         @type remote_path: C{str}
 
-        @raise X2goControlSessionException: if the SSH connection dropped out
+        @raise X2GoControlSessionException: if the SSH connection dropped out
 
         """
         ssh_transport = self.get_transport()
@@ -344,7 +355,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 self.session_died = True
                 self._transport_lock.release()
                 self.logger('sFTP-write: removing remote file %s on host %s failed' % (remote_path, self.remote_peername()), loglevel=log.loglevel_WARN)
-                raise x2go_exceptions.X2goControlSessionException('The SSH connection was dropped during an sFTP remove action.')
+                raise x2go_exceptions.X2GoControlSessionException('The SSH connection was dropped during an sFTP remove action.')
             self.sftp_client = None
             self._transport_lock.release()
 
@@ -367,7 +378,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @return: C{True} if the command could be successfully executed on the remote X2Go server
         @rtype: C{bool}
 
-        @raise X2goControlSessionException: if the command execution failed (due to a lost connection)
+        @raise X2GoControlSessionException: if the command execution failed (due to a lost connection)
 
         """
         if type(cmd_line) == types.ListType:
@@ -388,6 +399,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         ssh_transport = self.get_transport()
         if ssh_transport and ssh_transport.is_authenticated():
 
+            if self.low_latency: timeout = timeout * 2
             timer = gevent.Timeout(timeout)
             timer.start()
             try:
@@ -398,54 +410,89 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 self._transport_lock.release()
                 if self.sshproxy_session:
                     self.sshproxy_session.stop_thread()
-                raise x2go_exceptions.X2goControlSessionException('the X2Go control session has died unexpectedly')
+                raise x2go_exceptions.X2GoControlSessionException('the X2Go control session has died unexpectedly')
             except EOFError:
                 self.session_died = True
                 self._transport_lock.release()
                 if self.sshproxy_session:
                     self.sshproxy_session.stop_thread()
-                raise x2go_exceptions.X2goControlSessionException('the X2Go control session has died unexpectedly')
+                raise x2go_exceptions.X2GoControlSessionException('the X2Go control session has died unexpectedly')
             except x2go_exceptions.SSHException:
                 self.session_died = True
                 self._transport_lock.release()
                 if self.sshproxy_session:
                     self.sshproxy_session.stop_thread()
-                raise x2go_exceptions.X2goControlSessionException('the X2Go control session has died unexpectedly')
+                raise x2go_exceptions.X2GoControlSessionException('the X2Go control session has died unexpectedly')
             except gevent.timeout.Timeout:
                 self.session_died = True
                 self._transport_lock.release()
                 if self.sshproxy_session:
                     self.sshproxy_session.stop_thread()
-                raise x2go_exceptions.X2goControlSessionException('the X2Go control session command timed out')
+                raise x2go_exceptions.X2GoControlSessionException('the X2Go control session command timed out')
             except socket.error:
                 self.session_died = True
                 self._transport_lock.release()
                 if self.sshproxy_session:
                     self.sshproxy_session.stop_thread()
-                raise x2go_exceptions.X2goControlSessionException('the X2Go control session has died unexpectedly')
+                raise x2go_exceptions.X2GoControlSessionException('the X2Go control session has died unexpectedly')
             finally:
                 timer.cancel()
 
         else:
             self._transport_lock.release()
-            raise x2go_exceptions.X2goControlSessionException('the X2Go control session is not connected')
+            raise x2go_exceptions.X2GoControlSessionException('the X2Go control session is not connected')
 
         self._transport_lock.release()
         return _retval
 
+    @property
+    def _x2go_server_versions(self):
+        """\
+        Render a dictionary of server-side X2Go components and their versions. Results get cached
+        once there has been one successful query.
+
+        """
+        if self._server_versions is None:
+            self._server_versions = {}
+            (stdin, stdout, stderr) = self._x2go_exec_command('which x2goversion >/dev/null && x2goversion')
+            _lines = stdout.read().split('\n')
+            for _line in _lines:
+                if ':' not in _line: continue
+                comp = _line.split(':')[0].strip()
+                version = _line.split(':')[1].strip()
+                self._server_versions.update({comp: version})
+            self.logger('server-side X2Go components and their versions are: %s' % self._server_versions, loglevel=log.loglevel_DEBUG)
+        return self._server_versions
+
+    def query_server_versions(self, force=False):
+        """\
+        Do a query for the server-side list of X2Go components and their versions.
+
+        @param force: do not use the cached component list, really ask the server (again)
+        @type force: C{bool}
+
+        @return: dictionary of X2Go components (as keys) and their versions (as values)
+        @rtype: C{list}
+
+        """
+        if force:
+            self._server_versions = None
+        return self._x2go_server_versions
+    get_server_versions = query_server_versions
+
     @property
     def _x2go_server_features(self):
         """\
-        Render a list of server-side X2Go features. Results get cached once there has been one successfull query.
+        Render a list of server-side X2Go features. Results get cached once there has been one successful query.
 
         """
         if self._server_features is None:
             (stdin, stdout, stderr) = self._x2go_exec_command('which x2gofeaturelist >/dev/null && x2gofeaturelist')
             self._server_features = stdout.read().split('\n')
+            self._server_features = [ f for f in self._server_features if f ]
+            self._server_features.sort()
             self.logger('server-side X2Go features are: %s' % self._server_features, loglevel=log.loglevel_DEBUG)
-            return self._server_features
-        else:
-            return self._server_features
+        return self._server_features
 
     def query_server_features(self, force=False):
         """\
@@ -538,7 +585,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @return: SSH transport's user name
         @rtype: C{str}
 
-        @raise X2goControlSessionException: on SSH connection loss
+        @raise X2GoControlSessionException: on SSH connection loss
 
         """
         if self._remote_username is None:
@@ -547,7 +594,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                     self._remote_username = self.get_transport().get_username()
                 except:
                     self.session_died = True
-                    raise x2go_exceptions.X2goControlSessionException('Lost connection to X2Go server')
+                    raise x2go_exceptions.X2GoControlSessionException('Lost connection to X2Go server')
         return self._remote_username
 
     def remote_peername(self):
@@ -557,7 +604,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @return: SSH transport's peer name
         @rtype: C{tuple}
 
-        @raise X2goControlSessionException: on SSH connection loss
+        @raise X2GoControlSessionException: on SSH connection loss
 
         """
         if self._remote_peername is None:
@@ -566,7 +613,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                     self._remote_peername = self.get_transport().getpeername()
                 except:
                     self.session_died = True
-                    raise x2go_exceptions.X2goControlSessionException('Lost connection to X2Go server')
+                    raise x2go_exceptions.X2GoControlSessionException('Lost connection to X2Go server')
         return self._remote_peername
 
     @property
@@ -617,6 +664,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 sshproxy_key_filename='', sshproxy_pkey=None, sshproxy_look_for_keys=False, sshproxy_allow_agent=False,
                 sshproxy_tunnel='',
                 forward_sshagent=None,
+                unique_hostkey_aliases=None,
                 session_instance=None,
                 add_to_known_hosts=False, force_password_auth=False):
         """\
@@ -660,6 +708,8 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @param forward_sshagent: forward SSH agent authentication requests to the X2Go client-side
             (will update the class property of the same name)
         @type forward_sshagent: C{bool}
+        @param unique_hostkey_aliases: update the unique_hostkey_aliases class property
+        @type unique_hostkey_aliases: C{bool}
         @param timeout: an optional timeout (in seconds) for the TCP connect
         @type timeout: float
         @param look_for_keys: set to C{True} to enable searching for discoverable
@@ -675,7 +725,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @param force_password_auth: non-paramiko option, disable pub/priv key authentication 
             completely, even if the C{pkey} or the C{key_filename} parameter is given
         @type force_password_auth: C{bool}
-        @param session_instance: an instance L{X2goSession} using this L{X2goControlSessionSTDOUT}
+        @param session_instance: an instance L{X2GoSession} using this L{X2GoControlSessionSTDOUT}
             instance.
         @type session_instance: C{obj}
         @param use_sshproxy: connect through an SSH proxy
@@ -713,14 +763,26 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @raise SSHException: if there was any other error connecting or
             establishing an SSH session
         @raise socket.error: if a socket error occurred while connecting
-        @raise X2goSSHProxyException: any SSH proxy exception is passed through while establishing the SSH proxy connection and tunneling setup
-        @raise X2goSSHAuthenticationException: any SSH proxy authentication exception is passed through while establishing the SSH proxy connection and tunneling setup
-        @raise X2goRemoteHomeException: if the remote home directory does not exist or is not accessible
+        @raise X2GoSSHProxyException: any SSH proxy exception is passed through while establishing the SSH proxy connection and tunneling setup
+        @raise X2GoSSHAuthenticationException: any SSH proxy authentication exception is passed through while establishing the SSH proxy connection and tunneling setup
+        @raise X2GoRemoteHomeException: if the remote home directory does not exist or is not accessible
 
         """
+        _fake_hostname = None
+
+        if unique_hostkey_aliases is not None:
+            self.unique_hostkey_aliases = unique_hostkey_aliases
+            # prep the fake hostname with the real hostname, so we trigger the corresponding code path in 
+            # x2go.checkhosts and either of its missing host key policies
+            if self.unique_hostkey_aliases:
+                _fake_hostname = "[%s]:%s" % (hostname, port)
+
         if use_sshproxy and sshproxy_host and sshproxy_user:
             try:
-                self.sshproxy_session = sshproxy.X2goSSHProxy(known_hosts=self.known_hosts,
+
+                if not sshproxy_tunnel:
+                    sshproxy_tunnel = "localhost:44444:%s:%s" % (hostname, port)
+                self.sshproxy_session = sshproxy.X2GoSSHProxy(known_hosts=self.known_hosts,
                                                               sshproxy_host=sshproxy_host,
                                                               sshproxy_port=sshproxy_port,
                                                               sshproxy_user=sshproxy_user,
@@ -734,6 +796,11 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                                                               session_instance=session_instance,
                                                               logger=self.logger,
                                                              )
+                hostname = self.sshproxy_session.get_local_proxy_host()
+                port = self.sshproxy_session.get_local_proxy_port()
+                _fake_hostname = self.sshproxy_session.get_remote_host()
+                _fake_port = self.sshproxy_session.get_remote_port()
+                _fake_hostname = "[%s]:%s" % (_fake_hostname, _fake_port)
 
             except:
                 if self.sshproxy_session:
@@ -750,10 +817,10 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 port = self.sshproxy_session.get_local_proxy_port()
 
         if not add_to_known_hosts and session_instance:
-            self.set_missing_host_key_policy(checkhosts.X2goInteractiveAddPolicy(caller=self, session_instance=session_instance))
+            self.set_missing_host_key_policy(checkhosts.X2GoInteractiveAddPolicy(caller=self, session_instance=session_instance, fake_hostname=_fake_hostname))
 
         if add_to_known_hosts:
-            self.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+            self.set_missing_host_key_policy(checkhosts.X2GoAutoAddPolicy(caller=self, session_instance=session_instance, fake_hostname=_fake_hostname))
 
         # disable pub/priv key authentication if forced
         if force_password_auth:
@@ -776,6 +843,9 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         if forward_sshagent is not None:
             self.forward_sshagent = forward_sshagent
 
+        if timeout and self.low_latency:
+            timeout = timeout * 2
+
         if key_filename or pkey or look_for_keys or allow_agent or (password and force_password_auth):
             try:
                 if password and force_password_auth:
@@ -798,12 +868,17 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                         if str(e) == 'No authentication methods available':
                             raise paramiko.AuthenticationException('Interactive password authentication required!')
                         else:
+                            self.close()
+                            if self.sshproxy_session:
+                                self.sshproxy_session.stop_thread()
                             raise(e)
 
                 # since Paramiko 1.7.7.1 there is compression available, let's use it if present...
                 t = self.get_transport()
                 if x2go._paramiko.PARAMIKO_FEATURE['use-compression']:
                     t.use_compression(compress=True)
+                # enable keep alive callbacks
+                t.set_keepalive(5)
 
             except paramiko.AuthenticationException, e:
                 self.close()
@@ -858,7 +933,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         ssh_transport = self.get_transport()
         ssh_transport.reverse_tunnels = {}
 
-        # mark Paramiko/SSH transport as X2goControlSession
+        # mark Paramiko/SSH transport as X2GoControlSession
         ssh_transport._x2go_session_marker = True
         self._session_password = password
 
@@ -872,10 +947,17 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                     self.logger('Requesting SSH agent forwarding for control session of connected session profile %s' % self.profile_name, loglevel=log.loglevel_INFO)
                 else:
                     self.logger('SSH agent forwarding is not available in the Paramiko version used with this instance of Python X2Go', loglevel=log.loglevel_WARN)
+        else:
+            self.close()
+            if self.sshproxy_session:
+                self.sshproxy_session.stop_thread()
 
         self._remote_home = None
         if not self.home_exists():
-            raise x2go_exceptions.X2goRemoteHomeException('remote home directory does not exist')
+            self.close()
+            if self.sshproxy_session:
+                self.sshproxy_session.stop_thread()
+            raise x2go_exceptions.X2GoRemoteHomeException('remote home directory does not exist')
 
         return (self.get_transport() is not None)
 
@@ -884,7 +966,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         Drop an associated terminal session.
 
         @param terminal_session: the terminal session object to remove from the list of associated terminals
-        @type terminal_session: C{X2goTerminalSession*}
+        @type terminal_session: C{X2GoTerminalSession*}
 
         """
         for t_name in self.associated_terminals.keys():
@@ -907,9 +989,9 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 try:
                     if not self.session_died:
                         t_obj.suspend()
-                except x2go_exceptions.X2goTerminalSessionException:
+                except x2go_exceptions.X2GoTerminalSessionException:
                     pass
-                except x2go_exceptions.X2goControlSessionException:
+                except x2go_exceptions.X2GoControlSessionException:
                     self.session_died
                 t_obj.__del__()
             for t_name in t_names:
@@ -977,8 +1059,9 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         try:
             if self._x2go_exec_command('echo', loglevel=log.loglevel_DEBUG):
                 return True
-        except x2go_exceptions.X2goControlSessionException:
+        except x2go_exceptions.X2GoControlSessionException:
             self.session_died = True
+            self.disconnect()
         return False
 
     def has_session_died(self):
@@ -1191,8 +1274,8 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         """\
         Start a new X2Go session.
 
-        The L{X2goControlSessionSTDOUT.start()} method accepts any parameter
-        that can be passed to any of the C{X2goTerminalSession} backend class
+        The L{X2GoControlSessionSTDOUT.start()} method accepts any parameter
+        that can be passed to any of the C{X2GoTerminalSession} backend class
         constructors.
 
         @param kwargs: parameters that get passed through to the control session's
@@ -1213,26 +1296,25 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         """\
         Resume a running/suspended X2Go session. 
 
-        The L{X2goControlSessionSTDOUT.resume()} method accepts any parameter
-        that can be passed to any of the C{X2goTerminalSession*} backend class constructors.
+        The L{X2GoControlSessionSTDOUT.resume()} method accepts any parameter
+        that can be passed to any of the C{X2GoTerminalSession*} backend class constructors.
 
         @return: True if the session could be successfully resumed
         @rtype: C{bool}
 
-        @raise X2goUserException: if the remote user is not allowed to launch/resume X2Go sessions.
+        @raise X2GoUserException: if the remote user is not allowed to launch/resume X2Go sessions.
 
         """
         if not self.is_x2gouser(self.get_transport().get_username()):
-            raise x2go_exceptions.X2goUserException('remote user %s is not allowed to run X2Go commands' % self.get_transport().get_username())
+            raise x2go_exceptions.X2GoUserException('remote user %s is not allowed to run X2Go commands' % self.get_transport().get_username())
 
+        session_info = None
         try:
             if session_name is not None:
                 if session_list:
                     session_info = session_list[session_name]
                 else:
                     session_info = self.list_sessions()[session_name]
-            else:
-                session_info = None
         except KeyError:
             _success = False
 
@@ -1253,7 +1335,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 _success = _terminal.resume()
             else:
                 _success = _terminal.start()
-        except x2go_exceptions.X2goTerminalSessionException:
+        except x2go_exceptions.X2GoTerminalSessionException:
             _success = False
 
         if _success:
@@ -1290,7 +1372,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @return: True if the session could be successfully shared
         @rtype: C{bool}
 
-        @raise X2goDesktopSharingException: if C{username} and C{dislpay} do not relate to a
+        @raise X2GoDesktopSharingException: if C{username} and C{dislpay} do not relate to a
             sharable desktop session
 
         """
@@ -1298,7 +1380,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
             user = desktop.split('@')[0]
             display = desktop.split('@')[1]
         if not (user and display):
-            raise x2go_exceptions.X2goDesktopSharingException('Need user name and display number of sharable desktop.')
+            raise x2go_exceptions.X2GoDesktopSharingException('Need user name and display number of shared desktop.')
 
         cmd = '%sXSHAD%sXSHAD%s' % (share_mode, user, display)
 
@@ -1319,7 +1401,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @return: a list of X2Go desktops available for sharing
         @rtype: C{list}
 
-        @raise X2goTimeOutException: on command execution timeouts, with the server-side C{x2golistdesktops}
+        @raise X2GoTimeOutException: on command execution timeouts, with the server-side C{x2golistdesktops}
             command this can sometimes happen. Make sure you ignore these time-outs and to try again
 
         """
@@ -1332,6 +1414,9 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
             # this _success loop will catch errors in case the x2golistsessions output is corrupt
             # this should not be needed and is a workaround for the current X2Go server implementation
 
+            if self.low_latency:
+                maxwait = maxwait * 2
+
             timeout = gevent.Timeout(maxwait)
             timeout.start()
             try:
@@ -1342,7 +1427,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
                 # if we do not get a reply here after <maxwait> seconds we will raise a time out, we have to
                 # make sure that we catch this at places where we want to ignore timeouts (e.g. in the 
                 # desktop list cache)
-                raise x2go_exceptions.X2goTimeOutException('x2golistdesktop command timed out')
+                raise x2go_exceptions.X2GoTimeOutException('x2golistdesktop command timed out')
             finally:
                 timeout.cancel()
 
@@ -1363,7 +1448,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
         @return: a list of client-side mounts for X2Go session C{<session_name>} on the server
         @rtype: C{list}
 
-        @raise X2goTimeOutException: on command execution timeouts, queries with the server-side
+        @raise X2GoTimeOutException: on command execution timeouts, queries with the server-side
             C{x2golistmounts} query should normally be processed quickly, a time-out may hint that the
             control session has lost its connection to the X2Go server
 
@@ -1374,6 +1459,9 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
 
         else:
 
+            if self.low_latency:
+                maxwait = maxwait * 2
+
             # this _success loop will catch errors in case the x2golistmounts output is corrupt
 
             timeout = gevent.Timeout(maxwait)
@@ -1385,7 +1473,7 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
             except gevent.timeout.Timeout:
                 # if we do not get a reply here after <maxwait> seconds we will raise a time out, we have to
                 # make sure that we catch this at places where we want to ignore timeouts
-                raise x2go_exceptions.X2goTimeOutException('x2golistmounts command timed out')
+                raise x2go_exceptions.X2GoTimeOutException('x2golistmounts command timed out')
             finally:
                 timeout.cancel()
 
@@ -1399,16 +1487,19 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
             C{x2golistsessions} is returned.
         @type raw: C{bool}
 
-        @return: normally an instance of a C{X2goServerSessionList*} backend is returned. However,
+        @return: normally an instance of a C{X2GoServerSessionList*} backend is returned. However,
             if the raw argument is set, the plain text output of the server-side C{x2golistsessions}
             command is returned
-        @rtype: C{X2goServerSessionList} instance or str
+        @rtype: C{X2GoServerSessionList} instance or str
 
-        @raise X2goControlSessionException: on command execution timeouts, if this happens the control session will
+        @raise X2GoControlSessionException: on command execution timeouts, if this happens the control session will
             be interpreted as disconnected due to connection loss
         """
         if raw:
-            (stdin, stdout, stderr) = self._x2go_exec_command("export HOSTNAME && x2golistsessions")
+            if 'X2GO_LIST_SHADOWSESSIONS' in self._x2go_server_features:
+                (stdin, stdout, stderr) = self._x2go_exec_command("export HOSTNAME && { x2golistsessions; x2golistshadowsessions; }")
+            else:
+                (stdin, stdout, stderr) = self._x2go_exec_command("export HOSTNAME && x2golistsessions")
             return stdout.read(), stderr.read()
 
         else:
@@ -1425,7 +1516,10 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
             while not _success and _count < _maxwait:
                 _count += 1
                 try:
-                    (stdin, stdout, stderr) = self._x2go_exec_command("export HOSTNAME && x2golistsessions")
+                    if 'X2GO_LIST_SHADOWSESSIONS' in self._x2go_server_features:
+                        (stdin, stdout, stderr) = self._x2go_exec_command("export HOSTNAME && { x2golistsessions; x2golistshadowsessions; }")
+                    else:
+                        (stdin, stdout, stderr) = self._x2go_exec_command("export HOSTNAME && x2golistsessions")
                     _stdout_read = stdout.read()
                     _listsessions = self._list_backend(_stdout_read, info_backend=self._info_backend).sessions
                     _success = True
@@ -1438,7 +1532,8 @@ class X2goControlSessionSTDOUT(paramiko.SSHClient):
 
             if _count >= _maxwait:
                 self.session_died = True
-                raise x2go_exceptions.X2goControlSessionException('x2golistsessions command failed after we have tried 20 times')
+                self.disconnect()
+                raise x2go_exceptions.X2GoControlSessionException('x2golistsessions command failed after we have tried 20 times')
 
             # update internal variables when list_sessions() is called
             for _session_name, _terminal in self.associated_terminals.items():
