@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,9 +18,9 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goSessionProfiles} class - managing x2goclient session profiles.
+L{X2GoSessionProfiles} class - managing x2goclient session profiles.
 
-L{X2goSessionProfiles} is a public API class. Use this class in your Python X2Go based 
+L{X2GoSessionProfiles} is a public API class. Use this class in your Python X2Go based 
 applications.
 
 """
@@ -37,10 +37,10 @@ from x2go.defaults import X2GO_DESKTOPSESSIONS as _X2GO_DESKTOPSESSIONS
 import x2go.inifiles as inifiles
 import x2go.log as log
 import x2go.utils as utils
-from x2go.x2go_exceptions import X2goProfileException
+from x2go.x2go_exceptions import X2GoProfileException
 
 
-class X2goSessionProfilesFILE(inifiles.X2goIniFile):
+class X2GoSessionProfilesFILE(inifiles.X2GoIniFile):
 
     defaultSessionProfile = _X2GO_SESSIONPROFILE_DEFAULTS
     _non_profile_sections = ('embedded')
@@ -55,10 +55,10 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         @type defaults: C{dict}
         @param session_profile_defaults: a default session profile
         @type session_profile_defaults: C{dict}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goSessionProfilesFILE} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoSessionProfilesFILE} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -67,16 +67,17 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         self._profile_metatypes = {}
         self._cached_profile_ids = []
         self._cached_profile_names = []
+        self._profiles_need_profile_id_renewal = []
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
 
-        # providing defaults for an X2goSessionProfiles instance will---in the worst case---override your
+        # providing defaults for an X2GoSessionProfiles instance will---in the worst case---override your
         # existing sessions file in your home directory once you write the sessions back to file...
-        inifiles.X2goIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
+        inifiles.X2GoIniFile.__init__(self, config_files, defaults=defaults, logger=logger, loglevel=loglevel)
 
         if utils._checkSessionProfileDefaults(session_profile_defaults):
             self.defaultSessionProfile = session_profile_defaults
@@ -115,7 +116,6 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         @rtype: C{str}
 
         """
-
         _profile_id = self.check_profile_id_or_name(profile_id_or_name)
         if not self._profile_metatypes.has_key(_profile_id) or force:
             _config = self.get_profile_config(_profile_id)
@@ -146,6 +146,23 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         else:
             return self._profile_metatypes[_profile_id]
 
+    def write(self):
+
+        # then update profile IDs for profiles that have a renamed host attribute...
+        for profile_id in self._profiles_need_profile_id_renewal:
+            _config = self.get_profile_config(profile_id=profile_id)
+            self.iniConfig.remove_section(profile_id)
+            try: self._cached_profile_ids.remove(profile_id)
+            except ValueError: pass
+            self.add_profile(profile_id=None, **_config)
+        self._profiles_need_profile_id_renewal = []
+        self._cached_profile_ids = []
+        self._cached_profile_names = []
+
+        # at last write the profile config as is...
+        return inifiles.X2GoIniFile.write(self)
+
+
     def get_profile_option_type(self, option):
         """\
         Get the data type for a specific session profile option.
@@ -186,7 +203,7 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         @type profile_id_or_name: C{str}
         @param parameter: if specified, only the value for the given parameter is returned
         @type parameter: C{str}
-        @param profile_id: profile ID (fast than specifying C{profile_id_or_name})
+        @param profile_id: profile ID (faster than specifying C{profile_id_or_name})
         @type profile_id: C{str}
 
         @return: the session profile configuration for the given profile ID (or name)
@@ -217,7 +234,7 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
                 return value
 
             else:
-                raise X2goProfileException('no such session profile parameter: %s' % parameter)
+                raise X2GoProfileException('no such session profile parameter: %s' % parameter)
         return _profile_config
 
     def default_profile_config(self):
@@ -244,7 +261,7 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         try:
             self.check_profile_id_or_name(profile_id_or_name)
             return True
-        except X2goProfileException:
+        except X2GoProfileException:
             return False
 
     @property
@@ -310,7 +327,7 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         elif len(_profile_ids) == 0:
             return None
         else:
-            raise X2goProfileException('The sessions config file contains multiple session profiles with name: %s' % profile_name)
+            raise X2GoProfileException('The sessions config file contains multiple session profiles with name: %s' % profile_name)
 
     def to_profile_name(self, profile_id):
         """\
@@ -344,15 +361,13 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         """
         if profile_id is None:
             profile_id = utils._genSessionProfileId()
+
         for key, value in kwargs.items():
-            if key in self.defaultSessionProfile:
-                self.update_value(profile_id, key, value)
-            else:
-                raise X2goProfileException('keyword ,,%s\'\' not supported in X2Go session profile' % key)
+            self.update_value(None, key, value, profile_id=profile_id)
 
         for key, value in self.defaultSessionProfile.items():
             if key in kwargs: continue
-            self.update_value(profile_id, key, value)
+            self.update_value(None, key, value, profile_id=profile_id)
 
         self._cached_profile_ids = []
         self._cached_profile_names = []
@@ -374,7 +389,7 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         self._cached_profile_ids = []
         self._cached_profile_names = []
 
-    def update_value(self, section, key, value):
+    def update_value(self, section, key, value, profile_id=None):
         """\
         Update a value in a session profile.
 
@@ -387,21 +402,21 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
 
         """
         try:
-            profile_id = self.check_profile_id_or_name(section)
-        except X2goProfileException:
+            profile_id = profile_id or self.check_profile_id_or_name(section)
+        except X2GoProfileException:
             profile_id = section
+
         if key == 'name':
             profile_name = value
             current_profile_name = self.get_value(profile_id, key)
             if not profile_name:
-                raise X2goProfileException('profile name for profile id %s may not be empty' % profile_id)
+                raise X2GoProfileException('profile name for profile id %s may not be empty' % profile_id)
             else:
+                self._cached_profile_names = []
                 if profile_name != current_profile_name and profile_name in self.profile_names:
-                    raise X2goProfileException('a profile of name ,,%s'' already exists' % profile_name)
-            self._cached_profile_names = []
+                    raise X2GoProfileException('a profile of name ,,%s\'\' already exists' % profile_name)
 
         if key == 'export' and type(value) == types.DictType:
-
             _strvalue = '"'
             for folder in value.keys():
                 _strvalue += "%s:%s;" % (folder, int(value[folder]))
@@ -409,7 +424,12 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
             _strvalue = _strvalue.replace('""', '')
             value = _strvalue
 
-        inifiles.X2goIniFile.update_value(self, profile_id, key, value)
+        if key == 'host':
+            _config = self.get_profile_config(profile_id=profile_id)
+            if _config.has_key('host') and _config['host'] != value:
+                self._profiles_need_profile_id_renewal.append(profile_id)
+
+        inifiles.X2GoIniFile.update_value(self, profile_id, key, value)
 
     def check_profile_id_or_name(self, profile_id_or_name):
         """\
@@ -421,7 +441,7 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
         @return: profile ID
         @rtype: C{str}
 
-        @raise X2goProfileException: if no such session profile exists
+        @raise X2GoProfileException: if no such session profile exists
 
         """
         _profile_id = None
@@ -432,19 +452,19 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
             # we were given a session profile id...
             _profile_id = profile_id_or_name
         else:
-            raise X2goProfileException('No session profile with id or name ,,%s\'\' exists.' % profile_id_or_name)
+            raise X2GoProfileException('No session profile with id or name ,,%s\'\' exists.' % profile_id_or_name)
         return _profile_id
 
     def to_session_params(self, profile_id_or_name=None, profile_id=None):
         """\
-        Convert session profile options to L{X2goSession} constructor method parameters.
+        Convert session profile options to L{X2GoSession} constructor method parameters.
 
         @param profile_id_or_name: either profile ID or profile name is accepted
         @type profile_id_or_name: C{str}
         @param profile_id: profile ID (fast than specifying C{profile_id_or_name})
         @type profile_id: C{str}
 
-        @return: a dictionary of L{X2goSession} constructor method parameters
+        @return: a dictionary of L{X2GoSession} constructor method parameters
         @rtype: C{dict}
 
         """
@@ -453,11 +473,11 @@ class X2goSessionProfilesFILE(inifiles.X2goIniFile):
 
     def get_session_param(self, profile_id_or_name, param):
         """\
-        Get a single L{X2goSession} parameter from a specific session profile.
+        Get a single L{X2GoSession} parameter from a specific session profile.
 
         @param profile_id_or_name: either profile ID or profile name is accepted
         @type profile_id_or_name: C{str}
-        @param param: the parameter name in the L{X2goSession} constructor method
+        @param param: the parameter name in the L{X2GoSession} constructor method
         @type param: C{str}
 
         @return: the value of the session profile option represented by C{param}
