@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goTerminalSession class - core functions for handling your individual X2Go sessions.
+X2GoTerminalSession class - core functions for handling your individual X2Go sessions.
 
 This backend handles X2Go server implementations that respond with session infos 
 via server-side STDOUT and use NX3 as graphical proxy.
@@ -54,10 +54,10 @@ from x2go.defaults import X2GO_SESSIONS_ROOTDIR as _X2GO_SESSIONS_ROOTDIR
 from x2go.defaults import X2GO_GENERIC_APPLICATIONS as _X2GO_GENERIC_APPLICATIONS
 from x2go.defaults import X2GO_DESKTOPSESSIONS as _X2GO_DESKTOPSESSIONS
 
-from x2go.backends.info import X2goServerSessionInfo as _X2goServerSessionInfo
-from x2go.backends.info import X2goServerSessionList as _X2goServerSessionList
-from x2go.backends.proxy import X2goProxy as _X2goProxy
-from x2go.backends.printing import X2goClientPrinting as _X2goClientPrinting
+from x2go.backends.info import X2GoServerSessionInfo as _X2GoServerSessionInfo
+from x2go.backends.info import X2GoServerSessionList as _X2GoServerSessionList
+from x2go.backends.proxy import X2GoProxy as _X2GoProxy
+from x2go.backends.printing import X2GoClientPrinting as _X2GoClientPrinting
 
 _local_color_depth = utils.local_color_depth()
 
@@ -69,7 +69,7 @@ def _rewrite_cmd(cmd, params=None):
     @param cmd: the current command for execution (as found in the session profile parameter C{cmd})
     @type cmd: C{str}
     @param params: an session paramter object
-    @type params: L{X2goSessionParams}
+    @type params: L{X2GoSessionParams}
 
     @return: the rewritten command for server-side execution
     @rtype: C{str}
@@ -82,17 +82,20 @@ def _rewrite_cmd(cmd, params=None):
     if cmd in _X2GO_DESKTOPSESSIONS.keys():
         cmd = _X2GO_DESKTOPSESSIONS[cmd]
 
-    if (cmd == 'RDP') and (type(params) == X2goSessionParams):
+    if (cmd == 'RDP') and (type(params) == X2GoSessionParams):
+        _depth = params.depth
+        if int(_depth) == 17:
+            _depth = 16
         if params.geometry == 'fullscreen':
-            cmd = 'rdesktop -f -N %s %s -a %s' % (params.rdp_options, params.rdp_server, params.depth)
+            cmd = 'rdesktop -f -N %s %s -a %s' % (params.rdp_options, params.rdp_server, _depth)
         else:
-            cmd = 'rdesktop -g %s -N %s %s -a %s' % (params.geometry, params.rdp_options, params.rdp_server, params.depth)
+            cmd = 'rdesktop -g %s -N %s %s -a %s' % (params.geometry, params.rdp_options, params.rdp_server, _depth)
 
     # place quot marks around cmd if not empty string
     if cmd:
         cmd = '"%s"' % cmd
 
-    if ((type(params) == X2goSessionParams) and params.published_applications and cmd == ''):
+    if ((type(params) == X2GoSessionParams) and params.published_applications and cmd == ''):
         cmd = 'PUBLISHED'
 
     return cmd
@@ -115,10 +118,10 @@ def _rewrite_blanks(cmd):
     return cmd
 
 
-class X2goSessionParams(object):
+class X2GoSessionParams(object):
     """\
-    The L{X2goSessionParams} class is used to store all parameters that
-    C{X2goTerminalSession} backend objects are constructed with.
+    The L{X2GoSessionParams} class is used to store all parameters that
+    C{X2GoTerminalSession} backend objects are constructed with.
 
     """
     def rewrite_session_type(self):
@@ -166,12 +169,12 @@ class X2goSessionParams(object):
 
     def update(self, **properties_to_be_updated):
         """\
-        Update all properties in the object L{X2goSessionParams} object from
+        Update all properties in the object L{X2GoSessionParams} object from
         the passed on dictionary.
 
-        @param properties_to_be_updated: a dictionary with L{X2goSessionParams}
+        @param properties_to_be_updated: a dictionary with L{X2GoSessionParams}
             property names as keys und their values to be update in 
-            L{X2goSessionParams} object.
+            L{X2GoSessionParams} object.
         @type properties_to_be_updated: C{dict}
 
         """
@@ -180,25 +183,25 @@ class X2goSessionParams(object):
         self.rewrite_session_type()
 
 
-class X2goTerminalSessionSTDOUT(object):
+class X2GoTerminalSessionSTDOUT(object):
     """\
     Class for managing X2Go terminal sessions on a remote X2Go server via Paramiko/SSH.
 
-    With the L{X2goTerminalSessionSTDOUT} class you can start new X2Go sessions, resume suspended 
+    With the L{X2GoTerminalSessionSTDOUT} class you can start new X2Go sessions, resume suspended 
     sessions or suspend resp. terminate currently running sessions on a 
     connected X2Go server.
 
-    An L{X2goTerminalSessionSTDOUT} object uses two main data structure classes:
+    An L{X2GoTerminalSessionSTDOUT} object uses two main data structure classes:
 
-        - L{X2goSessionParams}: stores all parameters that have been passed to the 
+        - L{X2GoSessionParams}: stores all parameters that have been passed to the 
         constructor method.
 
-        - C{X2goServerSessionInfo*} backend class: when starting or resuming a session, an object of this class 
+        - C{X2GoServerSessionInfo*} backend class: when starting or resuming a session, an object of this class 
         will be used to store all information retrieved from the X2Go server.
 
     The terminal session instance works closely together (i.e. depends on) a connected control
-    session instance (e.g. L{X2goControlSessionSTDOUT}). You never should use either of them as a standalone
-    instance. Both, control session and terminal session(s) get managed/controlled via L{X2goSession} instances.
+    session instance (e.g. L{X2GoControlSessionSTDOUT}). You never should use either of them as a standalone
+    instance. Both, control session and terminal session(s) get managed/controlled via L{X2GoSession} instances.
 
     """
     def __init__(self, control_session, session_info=None,
@@ -214,16 +217,16 @@ class X2goTerminalSessionSTDOUT(object):
                  rootdir=None,
                  profile_name='UNKNOWN', profile_id=utils._genSessionProfileId(),
                  print_action=None, print_action_args={},
-                 info_backend=_X2goServerSessionInfo,
-                 list_backend=_X2goServerSessionList,
-                 proxy_backend=_X2goProxy, proxy_options={},
-                 printing_backend=_X2goClientPrinting,
+                 info_backend=_X2GoServerSessionInfo,
+                 list_backend=_X2GoServerSessionList,
+                 proxy_backend=_X2GoProxy, proxy_options={},
+                 printing_backend=_X2GoClientPrinting,
                  client_rootdir=os.path.join(_LOCAL_HOME, _X2GO_CLIENT_ROOTDIR),
                  sessions_rootdir=os.path.join(_LOCAL_HOME, _X2GO_SESSIONS_ROOTDIR),
                  session_instance=None,
                  logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        Initialize an X2Go session. With the L{X2goTerminalSessionSTDOUT} class you can start
+        Initialize an X2Go session. With the L{X2GoTerminalSessionSTDOUT} class you can start
         new X2Go sessions, resume suspended sessions or suspend resp. terminate
         currently running sessions on a connected X2Go server.
 
@@ -238,8 +241,8 @@ class X2goTerminalSessionSTDOUT(object):
         @type pack: C{str}
         @param dpi: dots-per-inch value for the session screen (has an impact on the font size on screen)
         @type dpi: C{str}
-        @param cache_type: a dummy parameter that is passed to the L{X2goProxyBASE}. In NX Proxy 
-            (class C{X2goProxyNX3}) this originally is the session name. With X2Go it 
+        @param cache_type: a dummy parameter that is passed to the L{X2GoProxyBASE}. In NX Proxy 
+            (class C{X2GoProxyNX3}) this originally is the session name. With X2Go it 
             defines the name of the NX cache directory. Best is to leave it untouched.
         @type cache_type: C{str}
         @param kbtype: keyboard type, e.g. C{pc105/us} (default), C{pc105/de}, ...
@@ -256,7 +259,7 @@ class X2goTerminalSessionSTDOUT(object):
         @param snd_port: local sound port for network capable audio system
         @type snd_port: C{int}
         @param cmd: command to be run on X2Go server after session start (only used
-            when L{X2goTerminalSessionSTDOUT.start()} is called, ignored on resume, suspend etc.
+            when L{X2GoTerminalSessionSTDOUT.start()} is called, ignored on resume, suspend etc.
         @type cmd: C{str}
         @param published_applications: session is published applications provider
         @type published_applications: C{bool}
@@ -285,30 +288,30 @@ class X2goTerminalSessionSTDOUT(object):
         @param profile_id: the session profile ID for this terminal session
         @type profile_id: C{str}
         @param print_action: either a print action short name (PDFVIEW, PDFSAVE, PRINT, PRINTCMD) or the
-            resp. C{X2goPrintActionXXX} class (where XXX equals one of the given short names)
+            resp. C{X2GoPrintActionXXX} class (where XXX equals one of the given short names)
         @type print_action: C{str} or C{class}
         @param print_action_args: optional arguments for a given print_action (for further info refer to
-            L{X2goPrintActionPDFVIEW}, L{X2goPrintActionPDFSAVE}, L{X2goPrintActionPRINT} and L{X2goPrintActionPRINTCMD})
+            L{X2GoPrintActionPDFVIEW}, L{X2GoPrintActionPDFSAVE}, L{X2GoPrintActionPRINT} and L{X2GoPrintActionPRINTCMD})
         @type print_action_args: dict
         @param info_backend: backend for handling storage of server session information
-        @type info_backend: C{X2goServerSessionInfo*} instance
+        @type info_backend: C{X2GoServerSessionInfo*} instance
         @param list_backend: backend for handling storage of session list information
-        @type list_backend: C{X2goServerSessionList*} instance
+        @type list_backend: C{X2GoServerSessionList*} instance
         @param proxy_backend: backend for handling the X-proxy connections
-        @type proxy_backend: C{X2goProxy*} instance
-        @param proxy_options: a set of very C{X2goProxy*} backend specific options; any option that is not known
-            to the C{X2goProxy*} backend will simply be ignored
+        @type proxy_backend: C{X2GoProxy*} instance
+        @param proxy_options: a set of very C{X2GoProxy*} backend specific options; any option that is not known
+            to the C{X2GoProxy*} backend will simply be ignored
         @type proxy_options: C{dict}
         @param client_rootdir: client base dir (default: ~/.x2goclient)
         @type client_rootdir: C{str}
         @param sessions_rootdir: sessions base dir (default: ~/.x2go)
         @type sessions_rootdir: C{str}
-        @param session_instance: the L{X2goSession} instance that is parent to this terminal session
+        @param session_instance: the L{X2GoSession} instance that is parent to this terminal session
         @type session_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goTerminalSessionSTDOUT} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoTerminalSessionSTDOUT} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -324,7 +327,7 @@ class X2goTerminalSessionSTDOUT(object):
         self.mimebox_queue = None
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -335,7 +338,7 @@ class X2goTerminalSessionSTDOUT(object):
         self.client_rootdir = client_rootdir
         self.sessions_rootdir = sessions_rootdir
 
-        self.params = X2goSessionParams()
+        self.params = X2GoSessionParams()
 
         self.params.geometry = str(geometry)
         self.params.link = str(link)
@@ -388,7 +391,7 @@ class X2goTerminalSessionSTDOUT(object):
             if self.session_info.name:
                 self.session_info.local_container = os.path.join(self.params.rootdir, 'S-%s' % self.session_info.name)
             else:
-                raise x2go_exceptions.X2goTerminalSessionException('no valid session info availble')
+                raise x2go_exceptions.X2GoTerminalSessionException('no valid session info availble')
         else:
             self.session_info = info_backend()
 
@@ -482,7 +485,7 @@ class X2goTerminalSessionSTDOUT(object):
         Retrieve the X2Go session's session info object.
 
         @return: the session info object
-        @rtype: C{X2goServerSessionInfo*}
+        @rtype: C{X2GoServerSessionInfo*}
 
         """
         return self.session_info
@@ -516,7 +519,7 @@ class X2goTerminalSessionSTDOUT(object):
             - PulseAudio
             - Esound (not tested very much)
 
-        @raise X2goControlSessionException: if the control session of this terminal session is not connected
+        @raise X2GoControlSessionException: if the control session of this terminal session is not connected
 
         """
         _tunnel = None
@@ -535,7 +538,7 @@ class X2goTerminalSessionSTDOUT(object):
                     self.control_session._x2go_sftp_put(local_path='%s/.pulse-cookie' % _LOCAL_HOME, remote_path='%s/.pulse-cookie' % self.session_info.remote_container)
 
                     # start reverse SSH tunnel for pulse stream
-                    _tunnel = rforward.X2goRevFwTunnel(server_port=self.session_info.snd_port, 
+                    _tunnel = rforward.X2GoRevFwTunnel(server_port=self.session_info.snd_port, 
                                                        remote_host='127.0.0.1', 
                                                        remote_port=self.snd_port, 
                                                        ssh_transport=self.control_session.get_transport(),
@@ -560,7 +563,7 @@ class X2goTerminalSessionSTDOUT(object):
                 self.control_session._x2go_sftp_put(local_path='%s/.esd_auth' % _LOCAL_HOME, remote_path='%s/.esd_auth' % self.control_session._x2go_remote_home)
 
                 # start reverse SSH tunnel for pulse stream
-                _tunnel = rforward.X2goRevFwTunnel(server_port=self.session_info.snd_port, 
+                _tunnel = rforward.X2GoRevFwTunnel(server_port=self.session_info.snd_port, 
                                                    remote_host='127.0.0.1', 
                                                    remote_port=self.snd_port, 
                                                    ssh_transport=self.control_session.get_transport(),
@@ -584,13 +587,13 @@ class X2goTerminalSessionSTDOUT(object):
 
         """
         if not self.control_session.is_sshfs_available():
-            raise x2go_exceptions.X2goUserException('Remote user %s is not allowed to share SSHFS resources with the server.' % self.session_info.username)
+            raise x2go_exceptions.X2GoUserException('Remote user %s is not allowed to share SSHFS resources with the server.' % self.session_info.username)
 
         # start reverse SSH tunnel for sshfs (folder sharing, printing)
         ssh_transport = self.control_session.get_transport()
         if self.reverse_tunnels[self.session_info.name]['sshfs'][1] is None:
 
-            _tunnel = sftpserver.X2goRevFwTunnelToSFTP(server_port=self.session_info.sshfs_port,
+            _tunnel = sftpserver.X2GoRevFwTunnelToSFTP(server_port=self.session_info.sshfs_port,
                                                        ssh_transport=ssh_transport,
                                                        auth_key=self.control_session._x2go_session_auth_rsakey,
                                                        session_instance=self.session_instance,
@@ -638,17 +641,17 @@ class X2goTerminalSessionSTDOUT(object):
         """\
         Initialize X2Go print spooling.
 
-        @raise X2goUserException: if the X2Go printing feature is not available to this user
+        @raise X2GoUserException: if the X2Go printing feature is not available to this user
 
         """
         if not self.control_session.is_sshfs_available():
-            raise x2go_exceptions.X2goUserException('Remote user %s is not allowed to use client-side printing.' % self.session_info.username)
+            raise x2go_exceptions.X2GoUserException('Remote user %s is not allowed to use client-side printing.' % self.session_info.username)
 
         spool_dir = os.path.join(self.session_info.local_container, 'spool')
         if not os.path.exists(spool_dir):
             os.makedirs(spool_dir)
         self.share_local_folder(local_path=spool_dir, folder_type='spool')
-        self.print_queue = printqueue.X2goPrintQueue(profile_name=self.profile_name,
+        self.print_queue = printqueue.X2GoPrintQueue(profile_name=self.profile_name,
                                                      session_name=self.session_info.name,
                                                      spool_dir=spool_dir,
                                                      print_action=self.print_action, 
@@ -664,10 +667,10 @@ class X2goTerminalSessionSTDOUT(object):
         """\
         Set a print action for the next incoming print jobs.
 
-        This method is a wrapper for L{X2goPrintQueue}C{.set_print_action()}.
+        This method is a wrapper for L{X2GoPrintQueue}C{.set_print_action()}.
 
-        @param print_action: print action name or object (i.e. an instance of C{X2goPrintAction*} classes)
-        @type print_action: C{str} or C{X2goPrintAction*}
+        @param print_action: print action name or object (i.e. an instance of C{X2GoPrintAction*} classes)
+        @type print_action: C{str} or C{X2GoPrintAction*}
         @param kwargs: print action specific parameters
         @type kwargs: dict
 
@@ -698,20 +701,20 @@ class X2goTerminalSessionSTDOUT(object):
 
         @param mimebox_extensions: file name extensions that are allowed for local opening/processing
         @type mimebox_extensions: C{list}
-        @param mimebox_action: MIME box action given as name or object (i.e. an instance of C{X2goMIMEboxAction*} classes).
+        @param mimebox_action: MIME box action given as name or object (i.e. an instance of C{X2GoMIMEboxAction*} classes).
         @type mimebox_action: C{str} or C{obj}
 
-        @raise X2goUserException: if the X2Go MIME box feature is not available to this user
+        @raise X2GoUserException: if the X2Go MIME box feature is not available to this user
 
         """
         if not self.control_session.is_sshfs_available():
-            raise x2go_exceptions.X2goUserException('Remote user %s is not allowed to use the MIME box.' % self.session_info.username)
+            raise x2go_exceptions.X2GoUserException('Remote user %s is not allowed to use the MIME box.' % self.session_info.username)
 
         mimebox_dir = os.path.join(self.session_info.local_container, 'mimebox')
         if not os.path.exists(mimebox_dir):
             os.makedirs(mimebox_dir)
         self.share_local_folder(local_path=mimebox_dir, folder_type='mimebox')
-        self.mimebox_queue = mimebox.X2goMIMEboxQueue(profile_name=self.profile_name,
+        self.mimebox_queue = mimebox.X2GoMIMEboxQueue(profile_name=self.profile_name,
                                                       session_name=self.session_info.name,
                                                       mimebox_dir=mimebox_dir,
                                                       mimebox_extensions=mimebox_extensions,
@@ -726,10 +729,10 @@ class X2goTerminalSessionSTDOUT(object):
         """\
         Set a MIME box action for the next incoming MIME jobs.
 
-        This method is a wrapper for L{X2goMIMEboxQueue}C{set_mimebox_action()}.
+        This method is a wrapper for L{X2GoMIMEboxQueue}C{set_mimebox_action()}.
 
-        @param mimebox_action: MIME box action name or object (i.e. an instance of C{X2goMIMEboxAction*} classes)
-        @type mimebox_action: C{str} or C{X2goMIMEboxAction*}
+        @param mimebox_action: MIME box action name or object (i.e. an instance of C{X2GoMIMEboxAction*} classes)
+        @type mimebox_action: C{str} or C{X2GoMIMEboxAction*}
         @param kwargs: MIME box action specific parameters
         @type kwargs: dict
 
@@ -792,12 +795,12 @@ class X2goTerminalSessionSTDOUT(object):
         @return: returns C{True} if the local folder has been successfully mounted within the X2Go server session
         @rtype: C{bool}
 
-        @raise X2goUserException: if local folder sharing is not available to this user
+        @raise X2GoUserException: if local folder sharing is not available to this user
         @raise Exception: any other exception occuring on the way is passed through by this method
 
         """
         if not self.control_session.is_sshfs_available():
-            raise x2go_exceptions.X2goUserException('Remote user %s is not allowed to share local folders with the server.' % self.session_info.username)
+            raise x2go_exceptions.X2GoUserException('Remote user %s is not allowed to share local folders with the server.' % self.session_info.username)
 
         if local_path is None:
             self.logger('no folder name given...', log.loglevel_WARN)
@@ -837,9 +840,17 @@ class X2goTerminalSessionSTDOUT(object):
             _server_encoding = self.params.server_encoding
 
             if _X2GOCLIENT_OS == 'Windows':
-                local_path = local_path.replace('\\', '/')
-                local_path = local_path.replace(':', '')
-                local_path = '/windrive/%s' % local_path
+                if local_path.startswith('\\\\'):
+                    # we are on a UNC path
+                    if 'X2GO_MOUNT_UNCPATHS' in self.control_session.get_server_features():
+                        local_path = local_path.repalce('\\\\', '/uncpath/')
+                    else:
+                        local_path = local_path.repalce('\\\\', '/windrive/')
+                    local_path = local_path.replace('\\', '/')
+                else:
+                    local_path = local_path.replace('\\', '/')
+                    local_path = local_path.replace(':', '')
+                    local_path = '/windrive/%s' % local_path
                 _convert_encoding = True
                 _client_encoding = 'WINDOWS-1252'
 
@@ -980,6 +991,18 @@ class X2goTerminalSessionSTDOUT(object):
                 # session title fallback... (like X2Go server does it...)
                 self.session_title = _generic_title
 
+        elif self.params.session_type == 'S':
+            if self.set_session_title:
+
+                shared_user = _generic_title.split('XSHAD')[1]
+                shared_display = _generic_title.split('XSHAD')[2].replace('PP', ':').split("_")[0]
+
+                self.session_title = 'Desktop %s@%s shared with %s@%s' % (shared_user, shared_display, self.control_session.remote_username(), self.control_session.get_hostname())
+
+            else:
+                # session title fallback... (like X2Go server does it...)
+                self.session_title = _generic_title
+
         else:
             # do nothing for rootless sessions
             self.session_title = _generic_title
@@ -1145,8 +1168,8 @@ class X2goTerminalSessionSTDOUT(object):
         """\
         Run a command in this session.
 
-        After L{X2goTerminalSessionSTDOUT.start()} has been called 
-        one or more commands can be executed with L{X2goTerminalSessionSTDOUT.run_command()}
+        After L{X2GoTerminalSessionSTDOUT.start()} has been called 
+        one or more commands can be executed with L{X2GoTerminalSessionSTDOUT.run_command()}
         within the current X2Go session.
 
         @param cmd: Command to be run
@@ -1355,7 +1378,7 @@ class X2goTerminalSessionSTDOUT(object):
         @return: C{True} if session startup has been successful and the X2Go proxy is up-and-running
         @rtype: C{bool}
 
-        @raise X2goTerminalSessionException: if the session startup failed
+        @raise X2GoTerminalSessionException: if the session startup failed
 
         """
         self.params.rewrite_session_type()
@@ -1410,7 +1433,7 @@ class X2goTerminalSessionSTDOUT(object):
         # if the first line of stdout is a "DEN(Y)" string then we will presume that
         # we tried to use X2Go desktop sharing and the sharing was rejected
         if "ACCESS DENIED" in _stderr and "XSHAD" in _stderr:
-            raise x2go_exceptions.X2goDesktopSharingException('X2Go desktop sharing has been denied by the remote user')
+            raise x2go_exceptions.X2GoDesktopSharingException('X2Go desktop sharing has been denied by the remote user')
 
         try:
             self.session_info.initialize(_stdout,
@@ -1418,9 +1441,9 @@ class X2goTerminalSessionSTDOUT(object):
                                          hostname=self.control_session.remote_peername(),
                                         )
         except ValueError:
-            raise x2go_exceptions.X2goTerminalSessionException("failed to start X2Go session")
+            raise x2go_exceptions.X2GoTerminalSessionException("failed to start X2Go session")
         except IndexError:
-            raise x2go_exceptions.X2goTerminalSessionException("failed to start X2Go session")
+            raise x2go_exceptions.X2GoTerminalSessionException("failed to start X2Go session")
 
         # local path may be a Windows path, so we use the path separator of the local system
         self.session_info.local_container = os.path.join(self.params.rootdir, 'S-%s' % self.session_info.name)
@@ -1450,7 +1473,7 @@ class X2goTerminalSessionSTDOUT(object):
                 self.control_session.get_published_applications()
 
         else:
-            raise x2go_exceptions.X2goTerminalSessionException("failed to start X2Go session")
+            raise x2go_exceptions.X2GoTerminalSessionException("failed to start X2Go session")
 
         return proxy_ok
 
@@ -1461,7 +1484,7 @@ class X2goTerminalSessionSTDOUT(object):
         @return: C{True} if the session could successfully be resumed
         @rtype: C{bool}
 
-        @raise X2goTerminalSessionException: if the terminal session failed to update server-side reported port changes
+        @raise X2GoTerminalSessionException: if the terminal session failed to update server-side reported port changes
 
         """
         setkbd = "0"
@@ -1499,7 +1522,7 @@ class X2goTerminalSessionSTDOUT(object):
                         self.logger('re-allocating graphics port for session %s, old server-side port is in use; new graphics port is %s' % (self.session_info, self.session_info.graphics_port), loglevel=log.loglevel_NOTICE)
                     except TypeError:
                         # if the re-allocation fails, this is fatal!!!
-                        raise x2go_exceptions.X2goTerminalSessionException('Failed to retrieve new graphics port from server. X2Go Session cannot be resumed.')
+                        raise x2go_exceptions.X2GoTerminalSessionException('Failed to retrieve new graphics port from server. X2Go Session cannot be resumed.')
                 elif 'sound_port=' in stdout_line and _new_value != str(self.session_info.snd_port):
                     try:
                         self.session_info.snd_port = int(_new_value)
@@ -1515,6 +1538,12 @@ class X2goTerminalSessionSTDOUT(object):
             except IndexError:
                 continue
 
+        # local path may be a Windows path, so we use the path separator of the local system
+        self.session_info.local_container = os.path.join(self.params.rootdir, 'S-%s' % self.session_info.name)
+        # remote path is always a UniX path...
+        self.session_info.remote_container = '%s/.x2go/C-%s' % (self.control_session._x2go_remote_home, 
+                                                                self.session_info.name,
+                                                               )
         self.proxy = self.proxy_backend(session_info=self.session_info, 
                                         ssh_transport=self.control_session.get_transport(), 
                                         sessions_rootdir=self.sessions_rootdir,
@@ -1524,12 +1553,6 @@ class X2goTerminalSessionSTDOUT(object):
         self.proxy_subprocess, proxy_ok = self.proxy.start_proxy()
 
         if proxy_ok:
-            # local path may be a Windows path, so we use the path separator of the local system
-            self.session_info.local_container = os.path.join(self.params.rootdir, 'S-%s' % self.session_info.name)
-            # remote path is always a UniX path...
-            self.session_info.remote_container = '%s/.x2go/C-%s' % (self.control_session._x2go_remote_home, 
-                                                                    self.session_info.name,
-                                                                   )
             self.params.depth = self.session_info.name.split('_')[2][2:]
 
             # on a session resume the user name comes in as a user ID. We have to translate this...
@@ -1547,7 +1570,7 @@ class X2goTerminalSessionSTDOUT(object):
                 self.control_session.get_published_applications()
                 self.published_applications = True
         else:
-            raise x2go_exceptions.X2goTerminalSessionException("failed to start X2Go session")
+            raise x2go_exceptions.X2GoTerminalSessionException("failed to start X2Go session")
 
         return proxy_ok
 
@@ -1613,3 +1636,48 @@ class X2goTerminalSessionSTDOUT(object):
                 self._rm_desktop_dirtree()
 
             self._cleaned_up = True
+
+    def is_desktop_session(self):
+        """\
+        Test if this terminal session is a desktop session.
+
+        @return: C{True} if this session is of session type desktop ('D').
+        @rtype: C{bool}
+
+        """
+        self.params.rewrite_session_type()
+        return self.params.session_type == 'D'
+
+    def is_rootless_session(self):
+        """\
+        Test if this terminal session is a rootless session.
+
+        @return: C{True} if this session is of session type rootless ('R').
+        @rtype: C{bool}
+
+        """
+        self.params.rewrite_session_type()
+        return self.params.session_type == 'R'
+
+    def is_shadow_session(self):
+        """\
+        Test if this terminal session is a desktop sharing (aka shadow) session.
+
+        @return: C{True} if this session is of session type shadow ('S').
+        @rtype: C{bool}
+
+        """
+        self.params.rewrite_session_type()
+        return self.params.session_type == 'S'
+
+    def is_pubapp_session(self):
+        """\
+        Test if this terminal session is a published applications session.
+
+        @return: C{True} if this session is of session type published applications ('P').
+        @rtype: C{bool}
+
+        """
+        self.params.rewrite_session_type()
+        return self.params.session_type == 'P'
+
