@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goListSessionCache class - caching X2Go session information.
+X2GoListSessionCache class - caching X2Go session information.
 
 """
 __NAME__ = 'x2gocache-pylib'
@@ -31,14 +31,14 @@ import gevent
 import log
 import x2go_exceptions
 
-class X2goListSessionsCache(object):
+class X2GoListSessionsCache(object):
     """\
     For non-blocking operations in client applications using Python X2Go, it is
-    recommended to enable the L{X2goListSessionsCache}. This can be done by calling
-    the constructor of the L{X2goClient} class.
+    recommended to enable the L{X2GoListSessionsCache}. This can be done by calling
+    the constructor of the L{X2GoClient} class.
 
     The session list and desktop cache gets updated in regular intervals by a threaded
-    L{X2goSessionGuardian} instance. For the session list and desktop list update, the
+    L{X2GoSessionGuardian} instance. For the session list and desktop list update, the
     X2Go server commands C{x2golistsessions} and C{x2godesktopsessions} are called and
     the command's stdout is cached in the session list cache.
 
@@ -52,11 +52,11 @@ class X2goListSessionsCache(object):
 
     def __init__(self, client_instance, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the L{X2goClient} instance that uses this L{X2goListSessionsCache}
+        @param client_instance: the L{X2GoClient} instance that uses this L{X2GoListSessionsCache}
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goListSessionsCache} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoListSessionsCache} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -66,7 +66,7 @@ class X2goListSessionsCache(object):
         self.protected = False
 
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -99,7 +99,7 @@ class X2goListSessionsCache(object):
 
     def update_all(self, update_sessions=True, update_desktops=False):
         """\
-        Update L{X2goListSessionsCache} for all connected session profiles.
+        Update L{X2GoListSessionsCache} for all connected session profiles.
 
         @param update_sessions: cache recent session lists from all connected servers
         @type update_sessions: C{bool}
@@ -114,7 +114,7 @@ class X2goListSessionsCache(object):
 
     def update(self, profile_name, update_sessions=True, update_desktops=False, update_mounts=False):
         """\
-        Update L{X2goListSessionsCache} (i.e. session/desktops) for session profile C{profile_name}.
+        Update L{X2GoListSessionsCache} (i.e. session/desktops) for session profile C{profile_name}.
 
         @param profile_name: name of profile to update
         @type profile_name: C{str}
@@ -141,75 +141,84 @@ class X2goListSessionsCache(object):
 
     def _update_mounts(self, profile_name, control_session):
         """\
-        Update mounts list of L{X2goListSessionsCache} for session profile C{profile_name}.
+        Update mounts list of L{X2GoListSessionsCache} for session profile C{profile_name}.
 
         @param profile_name: name of profile to update
         @type profile_name: C{str}
 
-        @raise X2goControlSessionException: if the control session's C{list_mounts} method fails
+        @raise X2GoControlSessionException: if the control session's C{list_mounts} method fails
         """
         try:
             self.x2go_listsessions_cache[profile_name]['mounts'] = {}
             if self.x2go_listsessions_cache[profile_name]['sessions']:
                 for session_name in self.x2go_listsessions_cache[profile_name]['sessions']:
-                    self.x2go_listsessions_cache[profile_name]['mounts'].update(control_session.list_mounts(session_name))
-        except x2go_exceptions.X2goControlSessionException, e:
+                    if self.client_instance.get_session_of_session_name(session_name, return_object=True, match_profile_name=profile_name).is_running():
+                        if control_session is not None and not control_session.has_session_died():
+                            self.x2go_listsessions_cache[profile_name]['mounts'].update(control_session.list_mounts(session_name))
+        except (x2go_exceptions.X2GoControlSessionException, AttributeError), e:
             if profile_name in self.x2go_listsessions_cache.keys():
                 del self.x2go_listsessions_cache[profile_name]
             self.protected = False
-            raise e
-        except x2go_exceptions.X2goTimeOutException:
+            raise x2go_exceptions.X2GoControlSessionException
+        except x2go_exceptions.X2GoTimeOutException:
+            pass
+        except KeyError:
             pass
 
     def _update_desktops(self, profile_name, control_session):
         """\
-        Update session lists of L{X2goListSessionsCache} for session profile C{profile_name}.
+        Update session lists of L{X2GoListSessionsCache} for session profile C{profile_name}.
 
         @param profile_name: name of profile to update
         @type profile_name: C{str}
         @param control_session: X2Go control session instance
         @type control_session: C{obj}
 
-        @raise X2goControlSessionException: if the control session's C{list_desktop} method fails
+        @raise X2GoControlSessionException: if the control session's C{list_desktop} method fails
         """
         try:
-            self.x2go_listsessions_cache[profile_name]['desktops'] = control_session.list_desktops()
-        except x2go_exceptions.X2goControlSessionException, e:
+            if control_session is not None and not control_session.has_session_died():
+                self.x2go_listsessions_cache[profile_name]['desktops'] = control_session.list_desktops()
+        except (x2go_exceptions.X2GoControlSessionException, AttributeError), e:
             if profile_name in self.x2go_listsessions_cache.keys():
                 del self.x2go_listsessions_cache[profile_name]
             self.protected = False
-            raise e
-        except x2go_exceptions.X2goTimeOutException:
+            raise x2go_exceptions.X2GoControlSessionException
+        except x2go_exceptions.X2GoTimeOutException:
+            pass
+        except KeyError:
             pass
 
     def _update_sessions(self, profile_name, control_session):
         """\
-        Update desktop list of L{X2goListSessionsCache} for session profile C{profile_name}.
+        Update desktop list of L{X2GoListSessionsCache} for session profile C{profile_name}.
 
         @param profile_name: name of profile to update
         @type profile_name: C{str}
 
-        @raise X2goControlSessionException: if the control session's C{list_sessions} method fails
+        @raise X2GoControlSessionException: if the control session's C{list_sessions} method fails
         """
         try:
-            if control_session is not None:
+            if control_session is not None and not control_session.has_session_died():
                 self.x2go_listsessions_cache[profile_name]['sessions'] = control_session.list_sessions()
-        except x2go_exceptions.X2goControlSessionException, e:
+        except (x2go_exceptions.X2GoControlSessionException, AttributeError), e:
             if profile_name in self.x2go_listsessions_cache.keys():
                 del self.x2go_listsessions_cache[profile_name]
             self.protected = False
-            raise e
+            raise x2go_exceptions.X2GoControlSessionException
+        except KeyError:
+            pass
 
     def list_sessions(self, session_uuid):
         """\
-        Retrieve a session list from the current cache content of L{X2goListSessionsCache}
-        for a given L{X2goSession} instance (specified by its unique session UUID).
+        Retrieve a session list from the current cache content of L{X2GoListSessionsCache}
+        for a given L{X2GoSession} instance (specified by its unique session UUID).
 
         @param session_uuid: unique identifier of session to query cache for
         @type session_uuid: C{str}
 
         @return: a data object containing available session information
-        @rtype: C{X2goServerSessionList*} instance (or C{None})
+        @rtype: C{X2GoServerSessionList*} instance (or C{None})
 
         """
         profile_name = self.client_instance.get_session_profile_name(session_uuid)
@@ -221,7 +230,7 @@ class X2goListSessionsCache(object):
     def list_desktops(self, session_uuid):
         """\
         Retrieve a list of available desktop sessions from the current cache content of
-        L{X2goListSessionsCache} for a given L{X2goSession} instance (specified by its 
+        L{X2GoListSessionsCache} for a given L{X2GoSession} instance (specified by its 
         unique session UUID).
 
         @param session_uuid: unique identifier of session to query cache for
@@ -240,7 +249,7 @@ class X2goListSessionsCache(object):
     def list_mounts(self, session_uuid):
         """\
         Retrieve a list of mounted client shares from the current cache content of
-        L{X2goListSessionsCache} for a given L{X2goSession} instance (specified by its 
+        L{X2GoListSessionsCache} for a given L{X2GoSession} instance (specified by its 
         unique session UUID).
 
         @param session_uuid: unique identifier of session to query cache for
@@ -272,8 +281,8 @@ class X2goListSessionsCache(object):
         if profile_name is None and session_uuid and self.client_instance:
             try:
                 profile_name = self.client_instance.get_session_profile_name(session_uuid)
-            except x2go_exceptions.X2goSessionRegistryException:
-                raise x2go_exceptions.X2goSessionCacheException("requested session UUID is not valid anymore")
+            except x2go_exceptions.X2GoSessionRegistryException:
+                raise x2go_exceptions.X2GoSessionCacheException("requested session UUID is not valid anymore")
         _is_profile_cached = self.x2go_listsessions_cache.has_key(profile_name)
         _is_cache_type_cached = _is_profile_cached and self.x2go_listsessions_cache[profile_name].has_key(cache_type)
         if cache_type is None:
