@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -96,56 +96,56 @@ else:
 ##
 
 BACKENDS_CONTROLSESSION = {
-    'STDOUT': 'X2goControlSessionSTDOUT',
+    'STDOUT': 'X2GoControlSessionSTDOUT',
 }
 BACKENDS_TERMINALSESSION = {
-    'STDOUT': 'X2goTerminalSessionSTDOUT',
+    'STDOUT': 'X2GoTerminalSessionSTDOUT',
 }
 BACKENDS_SERVERSESSIONINFO = {
-    'STDOUT': 'X2goServerSessionInfoSTDOUT',
+    'STDOUT': 'X2GoServerSessionInfoSTDOUT',
 }
 BACKENDS_SERVERSESSIONLIST = {
-    'STDOUT': 'X2goServerSessionListSTDOUT',
+    'STDOUT': 'X2GoServerSessionListSTDOUT',
 }
 BACKENDS_PROXY = {
-    'NX3': 'X2goProxyNX3',
+    'NX3': 'X2GoProxyNX3',
 }
 
-BACKEND_CONTROLSESSION_DEFAULT =  'X2goControlSessionSTDOUT'
-BACKEND_TERMINALSESSION_DEFAULT = 'X2goTerminalSessionSTDOUT'
-BACKEND_SERVERSESSIONINFO_DEFAULT = 'X2goServerSessionInfoSTDOUT'
-BACKEND_SERVERSESSIONLIST_DEFAULT = 'X2goServerSessionListSTDOUT'
-BACKEND_PROXY_DEFAULT = 'X2goProxyNX3'
+BACKEND_CONTROLSESSION_DEFAULT =  'X2GoControlSessionSTDOUT'
+BACKEND_TERMINALSESSION_DEFAULT = 'X2GoTerminalSessionSTDOUT'
+BACKEND_SERVERSESSIONINFO_DEFAULT = 'X2GoServerSessionInfoSTDOUT'
+BACKEND_SERVERSESSIONLIST_DEFAULT = 'X2GoServerSessionListSTDOUT'
+BACKEND_PROXY_DEFAULT = 'X2GoProxyNX3'
 
 ##
 ## profile backend defaults
 ##
 
 BACKENDS_SESSIONPROFILES = {
-    'FILE': 'X2goSessionProfilesFILE',
-    'GCONF': 'X2goSessionProfilesGCONF',
-    'HTTPSBROKER': 'X2goSessionProfilesHTTPSBROKER',
-    'WINREG': 'X2goSessionProfilesWINREG',
+    'FILE': 'X2GoSessionProfilesFILE',
+    'GCONF': 'X2GoSessionProfilesGCONF',
+    'HTTPSBROKER': 'X2GoSessionProfilesHTTPSBROKER',
+    'WINREG': 'X2GoSessionProfilesWINREG',
 }
 """Python X2Go backends for storing session profiles."""
 BACKENDS_CLIENTSETTINGS = {
-    'FILE': 'X2goClientSettingsFILE',
-    'GCONF': 'X2goClientSettingsGCONF',
-    'HTTPSBROKER': 'X2goClientSettingsHTTPSBROKER',
-    'WINREG': 'X2goClientSettingsWINREG',
+    'FILE': 'X2GoClientSettingsFILE',
+    'GCONF': 'X2GoClientSettingsGCONF',
+    'HTTPSBROKER': 'X2GoClientSettingsHTTPSBROKER',
+    'WINREG': 'X2GoClientSettingsWINREG',
 }
 """Python X2Go backends for storing client settings."""
 BACKENDS_CLIENTPRINTING = {
-    'FILE': 'X2goClientPrintingFILE',
-    'GCONF': 'X2goClientPrintingGCONF',
-    'HTTPSBROKER': 'X2goClientPrintingHTTPSBROKER',
-    'WINREG': 'X2goClientPrintingWINREG',
+    'FILE': 'X2GoClientPrintingFILE',
+    'GCONF': 'X2GoClientPrintingGCONF',
+    'HTTPSBROKER': 'X2GoClientPrintingHTTPSBROKER',
+    'WINREG': 'X2GoClientPrintingWINREG',
 }
 """Python X2Go backends for storing print settings."""
 
-BACKEND_SESSIONPROFILES_DEFAULT = 'X2goSessionProfilesFILE'
-BACKEND_CLIENTSETTINGS_DEFAULT = 'X2goClientSettingsFILE'
-BACKEND_CLIENTPRINTING_DEFAULT = 'X2goClientPrintingFILE'
+BACKEND_SESSIONPROFILES_DEFAULT = 'X2GoSessionProfilesFILE'
+BACKEND_CLIENTSETTINGS_DEFAULT = 'X2GoClientSettingsFILE'
+BACKEND_CLIENTPRINTING_DEFAULT = 'X2GoClientPrintingFILE'
 
 ##
 ## X2Go Printing
@@ -181,7 +181,7 @@ X2GO_CLIENTSETTINGS_DEFAULTS = {
         'port2': 0,
     },
     'General': {
-        # clientport is not needed for Python X2go
+        # clientport is not needed for Python X2Go
         'clientport': 22, 
         'autoresume': True,
     },
@@ -211,9 +211,9 @@ X2GO_CLIENTPRINTING_DEFAULTS = {
         'startcmd': False,
         # print command for non-CUPS printing
         'command': 'lpr',
-        # ignored in Python X2go
+        # ignored in Python X2Go
         'stdin': False,
-        # ignored in Python X2go
+        # ignored in Python X2Go
         'ps': False,
     },
     'save': {
@@ -289,18 +289,19 @@ else:
     X2GO_CLIENTXCONFIG_DEFAULTS = {}
 
 X2GO_GENERIC_APPLICATIONS = [ 'WWWBROWSER', 'MAILCLIENT', 'OFFICE', 'TERMINAL', ]
-"""X2go's generic applications."""
+"""X2Go's generic applications."""
 
 X2GO_SESSIONPROFILE_DEFAULTS = {
     'autologin': True, 'autoconnect': False, 'autostart': False, 'setsessiontitle': False, 'sessiontitle': "",
     'speed': 2, 'pack': '16m-jpeg', 'quality': 9,
     'iconvto': 'UTF-8', 'iconvfrom': 'UTF-8', 'useiconv': False,
-    'usesshproxy': False, 'sshproxyhost': 'proxyhost.mydomain', 'sshproxyport': 22, 'sshproxyuser': '', 'sshproxytunnel': 'localhost:44444:server.mydomain.private:22', 'sshproxykeyfile': '',
+    'usesshproxy': False, 'sshproxyhost': 'proxyhost.mydomain', 'sshproxyport': 22, 'sshproxyuser': '', 'sshproxykeyfile': '',
     'sshproxytype': 'SSH', 'sshproxysameuser': False, 'sshproxysamepass': False, 'sshproxyautologin': True,
+    'uniquehostkeyaliases': False,
     'useexports': True, 'restoreexports': False, 'fstunnel': True, 'export': '',
     'usemimebox': False, 'mimeboxextensions': '', 'mimeboxaction': 'OPEN',
     'fullscreen': False,
-    'width': 800,'height': 600, 'maxdim': False, 'dpi': 96, 'setdpi': False, 'xinerama': False, 'multidisp': False,
+    'width': 800,'height': 600, 'maxdim': False, 'dpi': 96, 'setdpi': False, 'xinerama': False, 'multidisp': False, 'display': 1,
     'usekbd': True, 'layout': 'us', 'type': 'pc105/us', 'variant': '',
     'sound': False, 'soundsystem': 'pulse', 'startsoundsystem': False, 'soundtunnel':True, 'defsndport':True, 'sndport':4713,
     'name': 'NEW_PROFILE', 'icon': ':icons/128x128/x2gosession.png',
@@ -311,7 +312,7 @@ X2GO_SESSIONPROFILE_DEFAULTS = {
     'print': False,
     'xdmcpserver': 'localhost',
 }
-"""L{X2goSessionProfiles} default values to fill a new session profile with."""
+"""L{X2GoSessionProfiles} default values to fill a new session profile with."""
 ##
 ## X2Go Proxy defaults
 ##
@@ -374,6 +375,7 @@ pack_methods_nx3.sort()
 ##
 
 X2GO_DESKTOPSESSIONS={
+    'CINNAMON': 'cinnamon',
     'KDE': 'startkde',
     'GNOME': 'gnome-session',
     'XFCE': 'xfce4-session',
@@ -381,7 +383,7 @@ X2GO_DESKTOPSESSIONS={
     'TRINITY': 'starttrinity',
     'UNITY': 'unity',
 }
-"""A dictionary with meta-commands for X2go's window manager sessions."""
+"""A dictionary with meta-commands for X2Go's window manager sessions."""
 
 ##
 ## X2Go SFTP server defaults
@@ -397,11 +399,11 @@ application instance.
 """
 
 X2GO_PRINT_ACTIONS = {
-    'PDFVIEW': 'X2goPrintActionPDFVIEW',
-    'PDFSAVE': 'X2goPrintActionPDFSAVE',
-    'PRINT': 'X2goPrintActionPRINT',
-    'PRINTCMD': 'X2goPrintActionPRINTCMD',
-    'DIALOG': 'X2goPrintActionDIALOG',
+    'PDFVIEW': 'X2GoPrintActionPDFVIEW',
+    'PDFSAVE': 'X2GoPrintActionPDFSAVE',
+    'PRINT': 'X2GoPrintActionPRINT',
+    'PRINTCMD': 'X2GoPrintActionPRINTCMD',
+    'DIALOG': 'X2GoPrintActionDIALOG',
 }
 """Relating print action names and classes."""
 
@@ -413,9 +415,9 @@ DEFAULT_PRINTCMD_CMD = 'lpr'
 """Default command for the PRINTCMD print action."""
 
 X2GO_MIMEBOX_ACTIONS = {
-    'OPEN': 'X2goMIMEboxActionOPEN',
-    'OPENWITH': 'X2goMIMEboxActionOPENWITH',
-    'SAVEAS': 'X2goMIMEboxActionSAVEAS',
+    'OPEN': 'X2GoMIMEboxActionOPEN',
+    'OPENWITH': 'X2GoMIMEboxActionOPENWITH',
+    'SAVEAS': 'X2GoMIMEboxActionSAVEAS',
 }
 """Relating MIME box action names and classes."""
 
