@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -36,13 +36,13 @@ from gevent.server import StreamServer
 import log
 from defaults import X2GOCLIENT_OS as _X2GOCLIENT_OS
 
-class X2goFwServer(StreamServer):
+class X2GoFwServer(StreamServer):
     """\
-    L{X2goFwServer} implements a gevent's StreamServer based Paramiko/SSH port
+    L{X2GoFwServer} implements a gevent's StreamServer based Paramiko/SSH port
     forwarding server.
 
-    An L{X2goFwServer} class object is used to tunnel graphical trafic
-    through an external proxy command launched by a C{X2goProxy*} backend.
+    An L{X2GoFwServer} class object is used to tunnel graphical trafic
+    through an external proxy command launched by a C{X2GoProxy*} backend.
 
     """
     def __init__ (self, listener, remote_host, remote_port, ssh_transport, session_instance=None, session_name=None, logger=None, loglevel=log.loglevel_DEFAULT,):
@@ -55,21 +55,21 @@ class X2goFwServer(StreamServer):
         @type remote_port: C{int}
         @param ssh_transport: a valid Paramiko/SSH transport object
         @type ssh_transport: C{obj}
-        @param session_instance: the complete L{X2goSession} instance of the X2Go session this port forwarding server belongs to.
-            Note: for new L{X2goSession} instances the object has the session name not yet set(!!!)
+        @param session_instance: the complete L{X2GoSession} instance of the X2Go session this port forwarding server belongs to.
+            Note: for new L{X2GoSession} instances the object has the session name not yet set(!!!)
         @type session_instance: C{obj}
         @param session_name: the session name of the X2Go session this port forwarding server belongs to
         @type session_name: C{str}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goFwServer} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoFwServer} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -78,6 +78,7 @@ class X2goFwServer(StreamServer):
         self.is_active = False
         self.failed = False
         self.keepalive = False
+        self.listener = listener
         self.chain_host = remote_host
         self.chain_port = remote_port
         self.ssh_transport = ssh_transport
@@ -86,7 +87,7 @@ class X2goFwServer(StreamServer):
 
         self.fw_socket = None
 
-        StreamServer.__init__(self, listener, self.x2go_forward_tunnel_handle)
+        StreamServer.__init__(self, self.listener, self.x2go_forward_tunnel_handle)
 
     def x2go_forward_tunnel_handle(self, fw_socket, address):
         """\
@@ -142,8 +143,9 @@ class X2goFwServer(StreamServer):
 
         else:
 
-            self.logger('connected!  Tunnel open %r -> %r -> %r' % (self.fw_socket.getpeername(),
-                        chan_peername, (self.chain_host, self.chain_port)),
+            self.logger('connected!  Tunnel open %r -> %r (on master connection %r -> %r)' % (
+                        self.listener, (self.chain_host, self.chain_port),
+                        self.fw_socket.getpeername(), chan_peername),
                         loglevel=log.loglevel_INFO)
 
             # once we are here, we can presume the tunnel to be active...
@@ -240,18 +242,18 @@ def start_forward_tunnel(local_host='127.0.0.1', local_port=22022,
     @type remote_port: C{int}
     @param ssh_transport: the Paramiko/SSH transport (i.e. the X2Go session's Paramiko/SSH transport object)
     @type ssh_transport: C{obj}
-    @param session_instance: the L{X2goSession} instance that initiates this tunnel
+    @param session_instance: the L{X2GoSession} instance that initiates this tunnel
     @type session_instance: C{obj}
     @param session_name: the session name of the X2Go session this port forwarding server belongs to
     @type session_name: C{str}
-    @param logger: an X2goLogger object
+    @param logger: an X2GoLogger object
     @type logger: C{obj}
 
-    @return: returns an L{X2goFwServer} instance
+    @return: returns an L{X2GoFwServer} instance
     @rtype: C{obj}
 
     """
-    fw_server = X2goFwServer(listener=(local_host, local_port),
+    fw_server = X2GoFwServer(listener=(local_host, local_port),
                              remote_host=remote_host, remote_port=remote_port,
                              ssh_transport=ssh_transport,
                              session_instance=session_instance, session_name=session_name,
@@ -262,7 +264,6 @@ def start_forward_tunnel(local_host='127.0.0.1', local_port=22022,
     except socket.error:
         fw_server.failed = True
         fw_server.is_active = False
-        pass
 
     return fw_server
 
@@ -270,7 +271,7 @@ def stop_forward_tunnel(fw_server):
     """\
     Tear down a given Paramiko/SSH port forwarding tunnel.
 
-    @param fw_server: an L{X2goFwServer} instance as returned by the L{start_forward_tunnel()} function
+    @param fw_server: an L{X2GoFwServer} instance as returned by the L{start_forward_tunnel()} function
     @type fw_server: C{obj}
 
     """
