@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -19,11 +19,11 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-L{X2goMIMEboxQueue} sets up a thread that listens for incoming files that
+L{X2GoMIMEboxQueue} sets up a thread that listens for incoming files that
 shall be opened locally on the client.
 
 For each file that gets dropped in the MIME box an individual 
-thread is started (L{X2goMIMEboxJob}) that handles the processing 
+thread is started (L{X2GoMIMEboxJob}) that handles the processing 
 of the incoming file.
 
 """
@@ -43,12 +43,12 @@ import log
 import mimeboxactions
 
 
-class X2goMIMEboxQueue(threading.Thread):
+class X2GoMIMEboxQueue(threading.Thread):
     """\
-    If the X2Go MIME box is supported in a particaluar L{X2goSession} instance
+    If the X2Go MIME box is supported in a particaluar L{X2GoSession} instance
     this class provides a sub-thread for handling incoming files in the MIME box
     directory. The actual handling of a dropped file is handled by the classes
-    L{X2goMIMEboxActionOPEN}, L{X2goMIMEboxActionOPENWITH} and L{X2goMIMEboxActionSAVEAS}.
+    L{X2GoMIMEboxActionOPEN}, L{X2GoMIMEboxActionOPENWITH} and L{X2GoMIMEboxActionSAVEAS}.
 
     """
     mimebox_action = None
@@ -67,18 +67,18 @@ class X2goMIMEboxQueue(threading.Thread):
         @type mimebox_dir: C{str}
         @param mimebox_action: name or instance of either of the possible X2Go print action classes
         @type mimebox_action: C{str} or instance
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintQueue} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintQueue} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -95,7 +95,7 @@ class X2goMIMEboxQueue(threading.Thread):
         self._accept_jobs = False
 
         if mimebox_action is None:
-            mimebox_action = mimeboxactions.X2goMIMEboxActionOPEN(client_instance=self.client_instance, logger=self.logger)
+            mimebox_action = mimeboxactions.X2GoMIMEboxActionOPEN(client_instance=self.client_instance, logger=self.logger)
         elif type(mimebox_action) in (types.StringType, types.UnicodeType):
             mimebox_action = self.set_mimebox_action(mimebox_action, client_instance=self.client_instance, logger=self.logger)
         else:
@@ -136,7 +136,7 @@ class X2goMIMEboxQueue(threading.Thread):
 
     def stop_thread(self):
         """\
-        Stops this L{X2goMIMEboxQueue} thread completely.
+        Stops this L{X2GoMIMEboxQueue} thread completely.
 
         """
         self.pause()
@@ -158,7 +158,7 @@ class X2goMIMEboxQueue(threading.Thread):
 
     def set_mimebox_action(self, mimebox_action, **kwargs):
         """\
-        Modify the MIME box action of this L{X2goMIMEboxQueue} thread during runtime. The 
+        Modify the MIME box action of this L{X2GoMIMEboxQueue} thread during runtime. The 
         change of the MIME box action will be valid for the next incoming file in the MIME box
         directory.
 
@@ -176,7 +176,7 @@ class X2goMIMEboxQueue(threading.Thread):
 
     def run(self):
         """\
-        This method gets called once the L{X2goMIMEboxQueue} thread is started by the C{X2goMIMEboxQueue.start()} method.
+        This method gets called once the L{X2GoMIMEboxQueue} thread is started by the C{X2GoMIMEboxQueue.start()} method.
 
         """
         self.logger('starting MIME box queue thread: %s' % repr(self), loglevel=log.loglevel_DEBUG)
@@ -190,7 +190,7 @@ class X2goMIMEboxQueue(threading.Thread):
 
                     for _job in self._incoming_mimebox_jobs:
                         self.logger('processing incoming X2Go MIME box job: %s' % _job, loglevel=log.loglevel_NOTICE)
-                        _new_mimeboxjob_thread = X2goMIMEboxJob(target=x2go_mimeboxjob_handler,
+                        _new_mimeboxjob_thread = X2GoMIMEboxJob(target=x2go_mimeboxjob_handler,
                                                                 kwargs={ 
                                                                   'mimebox_file': _job,
                                                                   'mimebox_extensions': self.mimebox_extensions,
@@ -213,15 +213,15 @@ def x2go_mimeboxjob_handler(mimebox_file=None,
                             parent_thread=None, logger=None, ):
     """\
     This function is called as a handler function for each incoming X2Go MIME box file
-    represented by the class L{X2goMIMEboxJob}.
+    represented by the class L{X2GoMIMEboxJob}.
 
     @param mimebox_file: MIME box file name as placed in to the X2Go MIME box spool directory
     @type mimebox_file: C{str}
-    @param mimebox_action: an instance of either of the possible C{X2goMIMEboxActionXXX} classes
-    @type mimebox_action: C{X2goMIMEboxActionXXX} nstance
-    @param parent_thread: the L{X2goMIMEboxQueue} thread that actually created this handler's L{X2goMIMEboxJob} instance
+    @param mimebox_action: an instance of either of the possible C{X2GoMIMEboxActionXXX} classes
+    @type mimebox_action: C{X2GoMIMEboxActionXXX} nstance
+    @param parent_thread: the L{X2GoMIMEboxQueue} thread that actually created this handler's L{X2GoMIMEboxJob} instance
     @type parent_thread: C{obj}
-    @param logger: the L{X2goMIMEboxQueue}'s logging instance
+    @param logger: the L{X2GoMIMEboxQueue}'s logging instance
     @type logger: C{obj}
 
     """
@@ -242,7 +242,7 @@ def x2go_mimeboxjob_handler(mimebox_file=None,
     elif _dotfile:
         logger('placing files starting with a dot (.<file>) into the X2Go MIME box is prohibited, ignoring the file ,,%s\'\'' % mimebox_file, loglevel=log.loglevel_WARN)
     else:
-        logger('file extension of MIME box file %s has been found in Python X2go\' hardcoded MIME box extenstions blacklist' % mimebox_file, loglevel=log.loglevel_WARN)
+        logger('file extension of MIME box file %s has been found in Python X2Go\' hardcoded MIME box extenstions blacklist' % mimebox_file, loglevel=log.loglevel_WARN)
 
     logger('removing MIME box file %s' % mimebox_file, loglevel=log.loglevel_DEBUG)
 
@@ -257,7 +257,7 @@ def x2go_mimeboxjob_handler(mimebox_file=None,
         parent_thread.mimebox_history = parent_thread.mimebox_history[-100:]
 
 
-class X2goMIMEboxJob(threading.Thread):
+class X2GoMIMEboxJob(threading.Thread):
     """\
     For each X2Go MIME box job we create a sub-thread that let's 
     the MIME box job be processed in the background.
