@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -20,7 +20,7 @@
 
 """\
 For MIME box jobs there are currently three handling actions available:
-L{X2goMIMEboxActionOPEN}, L{X2goMIMEboxActionOPENWITH} and L{X2goMIMEboxActionSAVEAS}.
+L{X2GoMIMEboxActionOPEN}, L{X2GoMIMEboxActionOPENWITH} and L{X2GoMIMEboxActionSAVEAS}.
 
 """
 __NAME__ = 'x2gomimeboxactions-pylib'
@@ -46,7 +46,7 @@ import x2go_exceptions
 _MIMEBOX_ENV = os.environ.copy()
 
 
-class X2goMIMEboxAction(object):
+class X2GoMIMEboxAction(object):
 
     __name__ = 'NAME'
     __description__ = 'DESCRIPTION'
@@ -56,23 +56,23 @@ class X2goMIMEboxAction(object):
         This is a meta class and has no functionality as such. It is used as parent
         class by »real« X2Go MIME box actions.
 
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goMIMEboxAction} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoMIMEboxAction} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
 
-        # these get set from within the X2goMIMEboxQueue class
+        # these get set from within the X2GoMIMEboxQueue class
         self.profile_name = 'UNKNOWN'
         self.session_name = 'UNKNOWN'
 
@@ -96,7 +96,7 @@ class X2goMIMEboxAction(object):
 
     def _do_process(self, mimebox_file, mimebox_dir, ):
         """\
-        Perform the defined MIME box action (doing nothing in L{X2goMIMEboxAction} parent class).
+        Perform the defined MIME box action (doing nothing in L{X2GoMIMEboxAction} parent class).
 
         @param mimebox_file: file name as placed in to the X2Go MIME box directory
         @type mimebox_file: C{str}
@@ -123,7 +123,7 @@ class X2goMIMEboxAction(object):
         self._do_process(mimebox_file, mimebox_dir)
 
 
-class X2goMIMEboxActionOPEN(X2goMIMEboxAction):
+class X2GoMIMEboxActionOPEN(X2GoMIMEboxAction):
     """\
     MIME box action that opens incoming files in the system's default application.
 
@@ -133,18 +133,18 @@ class X2goMIMEboxActionOPEN(X2goMIMEboxAction):
 
     def __init__(self, client_instance=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goMIMEboxActionOPEN} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoMIMEboxActionOPEN} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         self.client_instance = client_instance
-        X2goMIMEboxAction.__init__(self, logger=logger, loglevel=loglevel)
+        X2GoMIMEboxAction.__init__(self, logger=logger, loglevel=loglevel)
 
     def _do_process(self, mimebox_file, mimebox_dir, ):
         """\
@@ -180,7 +180,7 @@ class X2goMIMEboxActionOPEN(X2goMIMEboxAction):
             time.sleep(20)
 
 
-class X2goMIMEboxActionOPENWITH(X2goMIMEboxAction):
+class X2GoMIMEboxActionOPENWITH(X2GoMIMEboxAction):
     """\
     MIME box action that calls the system's ,,Open with...'' dialog on incoming files. Currently only
     properly implementable on Windows platforms.
@@ -191,18 +191,18 @@ class X2goMIMEboxActionOPENWITH(X2goMIMEboxAction):
 
     def __init__(self, client_instance=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goMIMEboxActionOPENWITH} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoMIMEboxActionOPENWITH} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         self.client_instance = client_instance
-        X2goMIMEboxAction.__init__(self, logger=logger, loglevel=loglevel)
+        X2GoMIMEboxAction.__init__(self, logger=logger, loglevel=loglevel)
 
     def _do_process(self, mimebox_file, mimebox_dir, ):
         """\
@@ -236,10 +236,10 @@ class X2goMIMEboxActionOPENWITH(X2goMIMEboxAction):
             time.sleep(20)
 
 
-class X2goMIMEboxActionSAVEAS(X2goMIMEboxAction):
+class X2GoMIMEboxActionSAVEAS(X2GoMIMEboxAction):
     """\
     MIME box action that allows saving incoming MIME box files to a local folder. What this 
-    MIME box actually does is calling a hook method in the L{X2goClient} instance that
+    MIME box actually does is calling a hook method in the L{X2GoClient} instance that
     can be hi-jacked by one of your application's methods which then can handle the ,,Save as...''
     request.
 
@@ -249,27 +249,27 @@ class X2goMIMEboxActionSAVEAS(X2goMIMEboxAction):
 
     def __init__(self, client_instance=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: an L{X2goClient} instance, within your customized L{X2goClient} make sure 
+        @param client_instance: an L{X2GoClient} instance, within your customized L{X2GoClient} make sure 
             you have a C{HOOK_open_mimebox_saveas_dialog(filename=<str>)} method defined that will actually
             handle the incoming mimebox file.
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goMIMEboxActionSAVEAS} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoMIMEboxActionSAVEAS} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
-        @raise X2goMIMEboxActionException: if the client_instance has not been passed to the SAVEAS MIME box action
+        @raise X2GoMIMEboxActionException: if the client_instance has not been passed to the SAVEAS MIME box action
 
         """
         if client_instance is None:
-            raise x2go_exceptions.X2goMIMEboxActionException('the SAVEAS MIME box action needs to know the X2goClient instance (client=<instance>)')
-        X2goMIMEboxAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
+            raise x2go_exceptions.X2GoMIMEboxActionException('the SAVEAS MIME box action needs to know the X2GoClient instance (client=<instance>)')
+        X2GoMIMEboxAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
 
     def _do_process(self, mimebox_file, mimebox_dir):
         """\
-        Call an L{X2goClient} hook method (C{HOOK_open_mimebox_saveas_dialog}) that
+        Call an L{X2GoClient} hook method (C{HOOK_open_mimebox_saveas_dialog}) that
         can handle the MIME box's SAVEAS action.
 
         @param mimebox_file: file name as placed in to the MIME box directory
@@ -282,7 +282,7 @@ class X2goMIMEboxActionSAVEAS(X2goMIMEboxAction):
         mimebox_file = os.path.normpath(mimebox_file)
         mimebox_dir = os.path.normpath(mimebox_dir)
 
-        self.logger('Session %s (%s) is calling X2goClient class hook method <client_instance>.HOOK_open_mimebox_saveas_dialog(%s)' % (self.session_name, self.profile_name, mimebox_file), loglevel=log.loglevel_NOTICE)
+        self.logger('Session %s (%s) is calling X2GoClient class hook method <client_instance>.HOOK_open_mimebox_saveas_dialog(%s)' % (self.session_name, self.profile_name, mimebox_file), loglevel=log.loglevel_NOTICE)
         self.client_instance.HOOK_open_mimebox_saveas_dialog(os.path.join(mimebox_dir, mimebox_file), profile_name=self.profile_name, session_name=self.session_name)
         time.sleep(60)
 
