@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -22,8 +22,8 @@
 Print jobs can either be sent to any of the local print queues (CUPS, Win32API),
 be opened in an external PDF viewer, be saved to a local folder or be handed 
 over to a custom (print) command. This is defined by four print action classes
-(L{X2goPrintActionDIALOG}, L{X2goPrintActionPDFVIEW}, L{X2goPrintActionPDFSAVE}, L{X2goPrintActionPRINT} and 
-L{X2goPrintActionPRINTCMD}).
+(L{X2GoPrintActionDIALOG}, L{X2GoPrintActionPDFVIEW}, L{X2GoPrintActionPDFSAVE}, L{X2GoPrintActionPRINT} and 
+L{X2GoPrintActionPRINTCMD}).
 
 """
 __NAME__ = 'x2goprintactions-pylib'
@@ -55,7 +55,7 @@ import x2go_exceptions
 _PRINT_ENV = os.environ.copy()
 
 
-class X2goPrintAction(object):
+class X2GoPrintAction(object):
 
     __name__ = 'NAME'
     __description__ = 'DESCRIPTION'
@@ -65,23 +65,23 @@ class X2goPrintAction(object):
         This is a meta class and has no functionality as such. It is used as parent 
         class by »real« X2Go print actions.
 
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintAction} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintAction} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
 
-        # these get set from within the X2goPrintQueue class
+        # these get set from within the X2GoPrintQueue class
         self.profile_name = 'UNKNOWN'
         self.session_name = 'UNKNOWN'
 
@@ -105,7 +105,7 @@ class X2goPrintAction(object):
 
     def _do_print(self, pdf_file, job_title, spool_dir, ):
         """
-        Perform the defined print action (doing nothing in L{X2goPrintAction} parent class).
+        Perform the defined print action (doing nothing in L{X2GoPrintAction} parent class).
 
         @param pdf_file: PDF file name as placed in to the X2Go spool directory
         @type pdf_file: C{str}
@@ -159,7 +159,7 @@ class X2goPrintAction(object):
         return _hr_path
 
 
-class X2goPrintActionPDFVIEW(X2goPrintAction):
+class X2GoPrintActionPDFVIEW(X2GoPrintAction):
     """\
     Print action that views incoming print job in an external PDF viewer application.
 
@@ -171,14 +171,14 @@ class X2goPrintActionPDFVIEW(X2goPrintAction):
 
     def __init__(self, client_instance=None, pdfview_cmd=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
         @param pdfview_cmd: command that starts the external PDF viewer application
         @type pdfview_cmd: C{str}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintActionPDFVIEW} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintActionPDFVIEW} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -186,7 +186,7 @@ class X2goPrintActionPDFVIEW(X2goPrintAction):
         if pdfview_cmd is None:
             pdfview_cmd = defaults.DEFAULT_PDFVIEW_CMD
         self.pdfview_cmd = pdfview_cmd
-        X2goPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
+        X2GoPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
 
     def _do_print(self, pdf_file, job_title, spool_dir, ):
         """\
@@ -237,7 +237,7 @@ class X2goPrintActionPDFVIEW(X2goPrintAction):
             os.remove(_hr_filename)
 
 
-class X2goPrintActionPDFSAVE(X2goPrintAction):
+class X2GoPrintActionPDFSAVE(X2GoPrintAction):
     """\
     Print action that saves incoming print jobs to a local folder.
 
@@ -249,14 +249,14 @@ class X2goPrintActionPDFSAVE(X2goPrintAction):
 
     def __init__(self, client_instance=None, save_to_folder=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
         @param save_to_folder: saving location for incoming print jobs (PDF files)
         @type save_to_folder: C{str}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintActionPDFSAVE} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintActionPDFSAVE} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -269,7 +269,7 @@ class X2goPrintActionPDFSAVE(X2goPrintAction):
             save_to_folder = os.path.expanduser(save_to_folder)
         self.save_to_folder = save_to_folder
 
-        X2goPrintAction.__init__(self, client_instance=client_instance, logger=None, loglevel=loglevel)
+        X2GoPrintAction.__init__(self, client_instance=client_instance, logger=None, loglevel=loglevel)
 
         self.logger('Save location for incoming PDFs is: %s' % self.save_to_folder, loglevel=log.loglevel_DEBUG)
         if not os.path.exists(self.save_to_folder):
@@ -294,7 +294,7 @@ class X2goPrintActionPDFSAVE(X2goPrintAction):
         shutil.copy2(pdf_file, dest_file)
 
 
-class X2goPrintActionPRINT(X2goPrintAction):
+class X2GoPrintActionPRINT(X2GoPrintAction):
     """\
     Print action that actually prints an incoming print job file.
 
@@ -304,20 +304,20 @@ class X2goPrintActionPRINT(X2goPrintAction):
 
     def __init__(self, client_instance=None, printer=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
         @param printer: name of the preferred printer, if C{None} the system's/user's default printer will be used
         @type printer: C{str}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintActionPRINT} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintActionPRINT} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         self.printer = printer
-        X2goPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
+        X2GoPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
 
     def _do_print(self, pdf_file, job_title, spool_dir, ):
         """\
@@ -420,12 +420,12 @@ class X2goPrintActionPRINT(X2goPrintAction):
             except OSError: pass
 
 
-class X2goPrintActionPRINTCMD(X2goPrintAction):
+class X2GoPrintActionPRINTCMD(X2GoPrintAction):
     """\
     Print action that calls an external command for further processing of incoming print jobs.
 
     The print job's PDF filename will be prepended as last argument to the print command
-    used in L{X2goPrintActionPRINTCMD} instances.
+    used in L{X2GoPrintActionPRINTCMD} instances.
 
     """
     __name__      = 'PRINTCMD'
@@ -433,14 +433,14 @@ class X2goPrintActionPRINTCMD(X2goPrintAction):
 
     def __init__(self, client_instance=None, print_cmd=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the underlying L{X2goClient} instance
+        @param client_instance: the underlying L{X2GoClient} instance
         @type client_instance: C{obj}
         @param print_cmd: external command to be called on incoming print jobs
         @type print_cmd: C{str}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintActionPRINTCMD} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintActionPRINTCMD} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
@@ -448,12 +448,12 @@ class X2goPrintActionPRINTCMD(X2goPrintAction):
         if print_cmd is None:
             print_cmd = defaults.DEFAULT_PRINTCMD_CMD
         self.print_cmd = print_cmd
-        X2goPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
+        X2GoPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
 
     def _do_print(self, pdf_file, job_title, spool_dir):
         """\
         Execute an external command that has been defined on construction 
-        of this L{X2goPrintActionPRINTCMD} instance.
+        of this L{X2GoPrintActionPRINTCMD} instance.
 
         @param pdf_file: PDF file name as placed in to the X2Go spool directory
         @type pdf_file: C{str}
@@ -481,11 +481,11 @@ class X2goPrintActionPRINTCMD(X2goPrintAction):
         except OSError: pass
 
 
-class X2goPrintActionDIALOG(X2goPrintAction):
+class X2GoPrintActionDIALOG(X2GoPrintAction):
     """\
     Print action that mediates opening a print dialog window. This class is rather empty,
     the actual print dialog box must be implemented in our GUI application (with the application's
-    L{X2goClient} instance.
+    L{X2GoClient} instance.
 
     """
     __name__      = 'DIALOG'
@@ -493,28 +493,28 @@ class X2goPrintActionDIALOG(X2goPrintAction):
 
     def __init__(self, client_instance=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: an L{X2goClient} instance, within your customized L{X2goClient} make sure 
+        @param client_instance: an L{X2GoClient} instance, within your customized L{X2GoClient} make sure 
             you have a C{HOOK_open_print_dialog(filename=<str>)} method defined that will actually
             open the print dialog.
         @type client_instance: C{obj}
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goPrintActionDIALOG} constructor
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoPrintActionDIALOG} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
-        @raise X2goPrintActionException: if the client_instance has not been passed to the DIALOG print action
+        @raise X2GoPrintActionException: if the client_instance has not been passed to the DIALOG print action
 
         """
         if client_instance is None:
-            raise x2go_exceptions.X2goPrintActionException('the DIALOG print action needs to know the X2goClient instance (client=<instance>)')
-        X2goPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
+            raise x2go_exceptions.X2GoPrintActionException('the DIALOG print action needs to know the X2GoClient instance (client=<instance>)')
+        X2GoPrintAction.__init__(self, client_instance=client_instance, logger=logger, loglevel=loglevel)
 
     def _do_print(self, pdf_file, job_title, spool_dir):
         """\
         Execute an external command that has been defined on construction 
-        of this L{X2goPrintActionPRINTCMD} instance.
+        of this L{X2GoPrintActionPRINTCMD} instance.
 
         @param pdf_file: PDF file name as placed in to the X2Go spool directory
         @type pdf_file: C{str}
@@ -527,8 +527,8 @@ class X2goPrintActionDIALOG(X2goPrintAction):
         pdf_file = os.path.normpath(pdf_file)
         spool_dir = os.path.normpath(spool_dir)
 
-        self.logger('Session %s (%s) is calling X2goClient class hook method <client_instance>.HOOK_open_print_dialog' % (self.session_name, self.profile_name), loglevel=log.loglevel_NOTICE)
+        self.logger('Session %s (%s) is calling X2GoClient class hook method <client_instance>.HOOK_open_print_dialog' % (self.session_name, self.profile_name), loglevel=log.loglevel_NOTICE)
         _new_print_action = self.client_instance.HOOK_open_print_dialog(profile_name=self.profile_name, session_name=self.session_name)
-        if type(_new_print_action) != type(self):
+        if _new_print_action and type(_new_print_action) != type(self):
             _new_print_action._do_print(pdf_file, job_title, spool_dir)
 
