@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """\
-X2goSessionRegistry class - the X2goClient's session registry backend
+X2GoSessionRegistry class - the X2GoClient's session registry backend
 
 """
 __NAME__ = 'x2gosessregistry-pylib'
@@ -37,13 +37,13 @@ import session
 import x2go_exceptions
 
 # import the default terminal session backend
-from x2go.backends.control import X2goControlSession as _X2goControlSession
-from x2go.backends.terminal import X2goTerminalSession as _X2goTerminalSession
-from x2go.backends.info import X2goServerSessionInfo as _X2goServerSessionInfo
-from x2go.backends.info import X2goServerSessionList as _X2goServerSessionList
-from x2go.backends.proxy import X2goProxy as _X2goProxy
-from x2go.backends.settings import X2goClientSettings as _X2goClientSettings
-from x2go.backends.printing import X2goClientPrinting as _X2goClientPrinting
+from x2go.backends.control import X2GoControlSession as _X2GoControlSession
+from x2go.backends.terminal import X2GoTerminalSession as _X2GoTerminalSession
+from x2go.backends.info import X2GoServerSessionInfo as _X2GoServerSessionInfo
+from x2go.backends.info import X2GoServerSessionList as _X2GoServerSessionList
+from x2go.backends.proxy import X2GoProxy as _X2GoProxy
+from x2go.backends.settings import X2GoClientSettings as _X2GoClientSettings
+from x2go.backends.printing import X2GoClientPrinting as _X2GoClientPrinting
 
 from defaults import LOCAL_HOME as _LOCAL_HOME
 from defaults import X2GO_CLIENT_ROOTDIR as _X2GO_CLIENT_ROOTDIR
@@ -51,26 +51,26 @@ from defaults import X2GO_SESSIONS_ROOTDIR as _X2GO_SESSIONS_ROOTDIR
 from defaults import X2GO_SESSIONPROFILE_DEFAULTS as _X2GO_SESSIONPROFILE_DEFAULTS
 from defaults import X2GO_SSH_ROOTDIR as _X2GO_SSH_ROOTDIR
 
-class X2goSessionRegistry(object):
+class X2GoSessionRegistry(object):
     """\
-    This class is utilized by L{X2goClient} instances to maintain a good overview on
-    session status of all associated L{X2goSession} instances.
+    This class is utilized by L{X2GoClient} instances to maintain a good overview on
+    session status of all associated L{X2GoSession} instances.
 
     """
     def __init__(self, client_instance,
                  logger=None, loglevel=log.loglevel_DEFAULT):
         """\
-        @param client_instance: the L{X2goClient} instance that instantiated this L{X2goSessionRegistry} instance.
-        @type client_instance: L{X2goClient} instance
-        @param logger: you can pass an L{X2goLogger} object to the L{X2goClientXConfig} constructor
+        @param client_instance: the L{X2GoClient} instance that instantiated this L{X2GoSessionRegistry} instance.
+        @type client_instance: L{X2GoClient} instance
+        @param logger: you can pass an L{X2GoLogger} object to the L{X2GoClientXConfig} constructor
         @type logger: C{obj}
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: C{int}
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -96,7 +96,7 @@ class X2goSessionRegistry(object):
         return self.registry.keys()
 
     def __repr__(self):
-        result = 'X2goSessionRegistry('
+        result = 'X2GoSessionRegistry('
         for p in dir(self):
             if '__' in p or not p in self.__dict__ or type(p) is types.InstanceType: continue
             result += p + '=' + str(self.__dict__[p]) + ','
@@ -105,21 +105,21 @@ class X2goSessionRegistry(object):
 
     def __call__(self, session_uuid):
         """\
-        Returns the L{X2goSession} instance for a given session UUID hash.
+        Returns the L{X2GoSession} instance for a given session UUID hash.
 
         @param session_uuid: the X2Go session's UUID registry hash
         @type session_uuid: C{str}
 
-        @return: the corresponding L{X2goSession} instance
-        @rtype: L{X2goSession} instance
+        @return: the corresponding L{X2GoSession} instance
+        @rtype: L{X2GoSession} instance
 
-        @raise X2goSessionRegistryException: if the given session UUID could not be found
+        @raise X2GoSessionRegistryException: if the given session UUID could not be found
 
         """
         try:
             return self.registry[session_uuid]
         except KeyError:
-            raise x2go_exceptions.X2goSessionRegistryException('No session found for UUID %s' % session_uuid)
+            raise x2go_exceptions.X2GoSessionRegistryException('No session found for UUID %s' % session_uuid)
 
     def disable_session_auto_registration(self):
         """\
@@ -229,7 +229,7 @@ class X2goSessionRegistry(object):
 
     def update_status(self, session_uuid=None, profile_name=None, profile_id=None, session_list=None, force_update=False, newly_connected=False):
         """\
-        Update the session status for L{X2goSession} that is represented by a given session UUID hash,
+        Update the session status for L{X2GoSession} that is represented by a given session UUID hash,
         profile name or profile ID.
 
         @param session_uuid: the X2Go session's UUID registry hash
@@ -240,23 +240,23 @@ class X2goSessionRegistry(object):
         @param profile_id: alternatively, a profile ID can be given (the stati of all registered sessions for this session 
             profile will be updated)
         @type profile_id: C{str}
-        @param session_list: an optional C{X2goServerSessionList*} instance (as returned by the L{X2goClient.list_sessions()} command can
+        @param session_list: an optional C{X2GoServerSessionList*} instance (as returned by the L{X2GoClient.list_sessions()} command can
             be passed to this method.
-        @type session_list: C{X2goServerSessionList*} instance
+        @type session_list: C{X2GoServerSessionList*} instance
         @param force_update: make sure the session status gets really updated
         @type force_update: C{bool}
 
         @return: C{True} if this method has been successful
         @rtype: C{bool}
 
-        @raise X2goSessionRegistryException: if the combination of C{session_uuid}, C{profile_name} and C{profile_id} does not match the requirement: 
+        @raise X2GoSessionRegistryException: if the combination of C{session_uuid}, C{profile_name} and C{profile_id} does not match the requirement: 
             only one of them
 
         """
         if session_uuid and profile_name or session_uuid and profile_id or profile_name and profile_id:
-            raise x2go_exceptions.X2goSessionRegistryException('only one of the possible method parameters is allowed (session_uuid, profile_name or profile_id)')
+            raise x2go_exceptions.X2GoSessionRegistryException('only one of the possible method parameters is allowed (session_uuid, profile_name or profile_id)')
         elif session_uuid is None and profile_name is None and profile_id is None:
-            raise x2go_exceptions.X2goSessionRegistryException('at least one of the method parameters session_uuid, profile_name or profile_id must be given')
+            raise x2go_exceptions.X2GoSessionRegistryException('at least one of the method parameters session_uuid, profile_name or profile_id must be given')
 
         if session_uuid:
             session_uuids = [ session_uuid ]
@@ -267,8 +267,8 @@ class X2goSessionRegistry(object):
 
         for _session_uuid in session_uuids:
 
-            # only operate on instantiated X2goSession objects
-            if type(self(_session_uuid)) != session.X2goSession:
+            # only operate on instantiated X2GoSession objects
+            if type(self(_session_uuid)) != session.X2GoSession:
                 continue
 
             if not self(_session_uuid).update_status(session_list=session_list, force_update=force_update):
@@ -278,7 +278,7 @@ class X2goSessionRegistry(object):
             _last_status = copy.deepcopy(self(_session_uuid)._last_status)
             _current_status = copy.deepcopy(self(_session_uuid)._current_status)
 
-            # at this point we hook into the X2goClient instance and call notification methods
+            # at this point we hook into the X2GoClient instance and call notification methods
             # that can be used to inform an application that something has happened
 
             _profile_name = self(_session_uuid).get_profile_name()
@@ -333,10 +333,6 @@ class X2goSessionRegistry(object):
                 if _profile_name in self.master_sessions.keys():
                     if self.master_sessions[_profile_name] == self(_session_uuid):
 
-                        # save exported folders to session profile config if requested by session profile parameter ,,restoreexports''...
-                        if self.client_instance and self(_session_uuid).restore_shared_local_folders:
-                            self.client_instance.set_profile_config(_profile_name, 'export', self(_session_uuid)._restore_exported_folders)
-
                         self(_session_uuid).unset_master_session()
                         del self.master_sessions[_profile_name]
 
@@ -350,19 +346,15 @@ class X2goSessionRegistry(object):
                 if _profile_name in self.master_sessions.keys():
                     if self.master_sessions[_profile_name] == self(_session_uuid):
 
-                        # save exported folders to session profile config if requested by session profile parameter ,,restoreexports''...
-                        if self.client_instance and self(_session_uuid).restore_shared_local_folders:
-                            self.client_instance.set_profile_config(_profile_name, 'export', self(_session_uuid)._restore_exported_folders)
-
                         self(_session_uuid).unset_master_session()
                         del self.master_sessions[_profile_name]
 
                 # session has terminated
                 self.client_instance.HOOK_on_session_has_terminated(session_uuid=_session_uuid, profile_name=_profile_name, session_name=_session_name)
                 try: self(_session_uuid).session_cleanup()
-                except x2go_exceptions.X2goSessionException: pass
+                except x2go_exceptions.X2GoSessionException: pass
                 try: self(_session_uuid).__del__()
-                except x2go_exceptions.X2goSessionException: pass
+                except x2go_exceptions.X2GoSessionException: pass
                 if len(self.virgin_sessions_of_profile_name(profile_name)) > 1:
                     self.forget(_session_uuid)
 
@@ -388,13 +380,13 @@ class X2goSessionRegistry(object):
 
     def register_available_server_sessions(self, profile_name, session_list=None, newly_connected=False, re_register=False, skip_pubapp_sessions=False):
         """\
-        Register server-side available X2Go sessions with this L{X2goSessionRegistry} instance for a given profile name.
+        Register server-side available X2Go sessions with this L{X2GoSessionRegistry} instance for a given profile name.
 
         @param profile_name: session profile name to register available X2Go sessions for
         @type profile_name: C{str}
-        @param session_list: an optional C{X2goServerSessionList*} instance (as returned by the L{X2goClient.list_sessions()} command can
+        @param session_list: an optional C{X2GoServerSessionList*} instance (as returned by the L{X2GoClient.list_sessions()} command can
             be passed to this method.
-        @type session_list: C{X2goServerSessionList*} instance
+        @type session_list: C{X2GoServerSessionList*} instance
         @param newly_connected: give a hint that the session profile got newly connected
         @type newly_connected: C{bool}
         @param re_register: re-register available sessions, needs to be done after changes to the session profile
@@ -424,7 +416,7 @@ class X2goSessionRegistry(object):
                 session_list = _ctrl_session.list_sessions()
 
             # make sure the session registry gets updated before registering new session
-            # (if the server name has changed, this will kick out obsolete X2goSessions)
+            # (if the server name has changed, this will kick out obsolete X2GoSessions)
             self.update_status(profile_name=profile_name, session_list=session_list, force_update=True)
             for session_name in session_list.keys():
                 if (session_name not in _session_names and not self._skip_auto_registration) or re_register:
@@ -467,13 +459,13 @@ class X2goSessionRegistry(object):
 
     def register(self, server, profile_id, profile_name,
                  session_name=None,
-                 control_backend=_X2goControlSession,
-                 terminal_backend=_X2goTerminalSession,
-                 info_backend=_X2goServerSessionInfo,
-                 list_backend=_X2goServerSessionList,
-                 proxy_backend=_X2goProxy,
-                 settings_backend=_X2goClientSettings,
-                 printing_backend=_X2goClientPrinting,
+                 control_backend=_X2GoControlSession,
+                 terminal_backend=_X2GoTerminalSession,
+                 info_backend=_X2GoServerSessionInfo,
+                 list_backend=_X2GoServerSessionList,
+                 proxy_backend=_X2GoProxy,
+                 settings_backend=_X2GoClientSettings,
+                 printing_backend=_X2GoClientPrinting,
                  client_rootdir=os.path.join(_LOCAL_HOME,_X2GO_CLIENT_ROOTDIR),
                  sessions_rootdir=os.path.join(_LOCAL_HOME,_X2GO_SESSIONS_ROOTDIR),
                  ssh_rootdir=os.path.join(_LOCAL_HOME,_X2GO_SSH_ROOTDIR),
@@ -482,7 +474,7 @@ class X2goSessionRegistry(object):
                  known_hosts=None,
                  **kwargs):
         """\
-        Register a new L{X2goSession} instance with this L{X2goSessionRegistry}.
+        Register a new L{X2GoSession} instance with this L{X2GoSessionRegistry}.
 
         @param server: hostname of X2Go server
         @type server: C{str}
@@ -512,13 +504,13 @@ class X2goSessionRegistry(object):
         @type sessions_rootdir: C{str}
         @param ssh_rootdir: ssh base dir (default: ~/.ssh)
         @type ssh_rootdir: C{str}
-        @param keep_controlsession_alive: On last L{X2goSession.disconnect()} keep the associated C{X2goControlSession*} instance alive?
+        @param keep_controlsession_alive: On last L{X2GoSession.disconnect()} keep the associated C{X2GoControlSession*} instance alive?
         @ŧype keep_controlsession_alive: C{bool}
         @param add_to_known_hosts: Auto-accept server host validity?
         @type add_to_known_hosts: C{bool}
         @param known_hosts: the underlying Paramiko/SSH systems C{known_hosts} file
         @type known_hosts: C{str}
-        @param kwargs: all other options will be passed on to the constructor of the to-be-instantiated L{X2goSession} instance
+        @param kwargs: all other options will be passed on to the constructor of the to-be-instantiated L{X2GoSession} instance
         @type C{dict}
 
         @return: the session UUID of the newly registered (or re-registered) session
@@ -537,7 +529,7 @@ class X2goSessionRegistry(object):
         try:
             _params = self.client_instance.session_profiles.to_session_params(profile_id)
 
-        except x2go_exceptions.X2goProfileException:
+        except x2go_exceptions.X2GoProfileException:
             _params = utils._convert_SessionProfileOptions_2_SessionParams(_X2GO_SESSIONPROFILE_DEFAULTS)
 
         for _k in _params.keys():
@@ -553,7 +545,7 @@ class X2goSessionRegistry(object):
             self.logger('using already initially-registered yet-unused session %s' % session_uuid, loglevel=log.loglevel_NOTICE)
 
         else:
-            session_uuid = self.get_session_of_session_name(session_name)
+            session_uuid = self.get_session_of_session_name(session_name, match_profile_name=profile_name)
             if session_uuid is not None: self.logger('using already registered-by-session-name session %s' % session_uuid, loglevel=log.loglevel_NOTICE)
 
         if session_uuid is not None:
@@ -571,7 +563,7 @@ class X2goSessionRegistry(object):
         try: del _params['profile_id'] 
         except: pass
 
-        s = session.X2goSession(server=server, control_session=control_session,
+        s = session.X2GoSession(server=server, control_session=control_session,
                                 profile_id=profile_id, profile_name=profile_name,
                                 session_name=session_name,
                                 control_backend=control_backend,
@@ -590,7 +582,7 @@ class X2goSessionRegistry(object):
                                 client_instance=self.client_instance,
                                 logger=self.logger, **_params)
 
-        session_uuid = s._X2goSession__get_uuid()
+        session_uuid = s._X2GoSession__get_uuid()
         self.logger('registering X2Go session %s...' % profile_name, log.loglevel_NOTICE)
         self.logger('registering X2Go session with UUID %s' % session_uuid, log.loglevel_DEBUG)
 
@@ -606,36 +598,44 @@ class X2goSessionRegistry(object):
         self._profile_locks[profile_id].release()
         return session_uuid
 
-    def has_session_of_session_name(self, session_name):
+    def has_session_of_session_name(self, session_name, match_profile_name=None):
         """\
-        Detect if we know about an L{X2goSession} of name C{<session_name>}.
+        Detect if we know about an L{X2GoSession} of name C{<session_name>}.
 
         @param session_name: name of session to be searched for
         @type session_name: C{str}
+        @param match_profile_name: a session's profile_name must match this profile name
+        @type match_profile_name: C{str}
 
         @return: C{True} if a session of C{<session_name>} has been found
         @rtype: C{bool}
 
         """
-        return bool(self.get_session_of_session_name(session_name))
+        return bool(self.get_session_of_session_name(session_name, match_profile_name=match_profile_name))
 
-    def get_session_of_session_name(self, session_name, return_object=False):
+    def get_session_of_session_name(self, session_name, return_object=False, match_profile_name=None):
         """\
-        Retrieve the L{X2goSession} instance with session name C{<session_name>}.
+        Retrieve the L{X2GoSession} instance with session name C{<session_name>}.
 
         @param session_name: name of session to be retrieved
         @type session_name: C{str}
-        @param return_object: if C{False} the session UUID hash will be returned, if C{True} the L{X2goSession} instance will be returned
+        @param return_object: if C{False} the session UUID hash will be returned, if C{True} the L{X2GoSession} instance will be returned
         @type return_object: C{bool}
+        @param match_profile_name: returned sessions must match this profile name
+        @type match_profile_name: C{str}
 
-        @return: L{X2goSession} object or its representing session UUID hash
-        @rtype: L{X2goSession} instance or C{str}
+        @return: L{X2GoSession} object or its representing session UUID hash
+        @rtype: L{X2GoSession} instance or C{str}
 
-        @raise X2goSessionRegistryException: if there is more than one L{X2goSession} registered for C{<session_name>} within
-            the same L{X2goClient} instance. This should never happen!
+        @raise X2GoSessionRegistryException: if there is more than one L{X2GoSession} registered for C{<session_name>} within
+            the same L{X2GoClient} instance. This should never happen!
 
         """
-        found_sessions = [ s for s in self.registered_sessions() if s.session_name == session_name and s.session_name is not None ]
+        if match_profile_name is None:
+            reg_sessions = self.registered_sessions()
+        else:
+            reg_sessions = self.registered_sessions_of_profile_name(match_profile_name)
+        found_sessions = [ s for s in reg_sessions if s.session_name == session_name and s.session_name is not None ]
         if len(found_sessions) == 1:
             session = found_sessions[0]
             if return_object:
@@ -643,7 +643,7 @@ class X2goSessionRegistry(object):
             else:
                 return session.get_uuid()
         elif len(found_sessions) > 1:
-            raise x2go_exceptions.X2goSessionRegistryException('there should only be one registered session of name ,,%s\'\'' % session_name)
+            raise x2go_exceptions.X2GoSessionRegistryException('there should only be one registered session of name ,,%s\'\'' % session_name)
         else:
             return None
 
@@ -679,10 +679,10 @@ class X2goSessionRegistry(object):
 
     def connected_sessions(self, return_objects=True, return_profile_names=False, return_profile_ids=False, return_session_names=False):
         """\
-        Retrieve a list of sessions that the underlying L{X2goClient} instances is currently connected to.
+        Retrieve a list of sessions that the underlying L{X2GoClient} instances is currently connected to.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -699,10 +699,10 @@ class X2goSessionRegistry(object):
 
     def associated_sessions(self, return_objects=True, return_profile_names=False, return_profile_ids=False, return_session_names=False):
         """\
-        Retrieve a list of sessions that are currently associated by an C{X2goTerminalSession*} to the underlying L{X2goClient} instance.
+        Retrieve a list of sessions that are currently associated by an C{X2GoTerminalSession*} to the underlying L{X2GoClient} instance.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -722,7 +722,7 @@ class X2goSessionRegistry(object):
         Retrieve a list of sessions that are currently still in virgin state (not yet connected, associated etc.).
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -742,7 +742,7 @@ class X2goSessionRegistry(object):
         Retrieve a list of sessions that are currently in running state.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -762,7 +762,7 @@ class X2goSessionRegistry(object):
         Retrieve a list of sessions that are currently in suspended state.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -782,7 +782,7 @@ class X2goSessionRegistry(object):
         Retrieve a list of sessions that have terminated recently.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -800,7 +800,7 @@ class X2goSessionRegistry(object):
     @property
     def has_running_sessions(self):
         """\
-        Equals C{True} if the underlying L{X2goClient} instance has any running sessions at hand.
+        Equals C{True} if the underlying L{X2GoClient} instance has any running sessions at hand.
 
         """
         return self.running_sessions() and len(self.running_sessions()) > 0
@@ -808,7 +808,7 @@ class X2goSessionRegistry(object):
     @property
     def has_suspended_sessions(self):
         """\
-        Equals C{True} if the underlying L{X2goClient} instance has any suspended sessions at hand.
+        Equals C{True} if the underlying L{X2GoClient} instance has any suspended sessions at hand.
 
         """
         return self.suspended_sessions and len(self.suspended_sessions) > 0
@@ -818,7 +818,7 @@ class X2goSessionRegistry(object):
         Retrieve a list of all registered sessions.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -838,7 +838,7 @@ class X2goSessionRegistry(object):
         Retrieve a list of sessions that are currently _NOT_ in running state.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_profile_names: return as list of profile names
         @type return_profile_names: C{bool}
@@ -860,7 +860,7 @@ class X2goSessionRegistry(object):
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -878,12 +878,12 @@ class X2goSessionRegistry(object):
 
     def associated_sessions_of_profile_name(self, profile_name, return_objects=True, return_session_names=False):
         """\
-        For a given session profile name retrieve a list of sessions that are currently associated by an C{X2goTerminalSession*} to this L{X2goClient} instance.
+        For a given session profile name retrieve a list of sessions that are currently associated by an C{X2GoTerminalSession*} to this L{X2GoClient} instance.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -906,7 +906,7 @@ class X2goSessionRegistry(object):
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -924,12 +924,12 @@ class X2goSessionRegistry(object):
 
     def registered_sessions_of_profile_name(self, profile_name, return_objects=True, return_session_names=False):
         """\
-        For a given session profile name retrieve a list of sessions that are currently registered with this L{X2goClient} instance.
+        For a given session profile name retrieve a list of sessions that are currently registered with this L{X2GoClient} instance.
         If none of the C{return_*} options is specified a list of session UUID hashes will be returned.
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -938,7 +938,6 @@ class X2goSessionRegistry(object):
         @rtype: C{list}
 
         """
-
         if return_objects:
             return self.registered_sessions() and [ s for s in self.registered_sessions() if s.get_profile_name() == profile_name ]
         elif return_session_names:
@@ -948,13 +947,13 @@ class X2goSessionRegistry(object):
 
     def virgin_sessions_of_profile_name(self, profile_name, return_objects=True, return_session_names=False):
         """\
-        For a given session profile name retrieve a list of sessions that are registered with this L{X2goClient} instance but have not
+        For a given session profile name retrieve a list of sessions that are registered with this L{X2GoClient} instance but have not
         yet been started (i.e. sessions that are in virgin state). If none of the C{return_*} options is specified a list of 
         session UUID hashes will be returned.
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -977,7 +976,7 @@ class X2goSessionRegistry(object):
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -1000,7 +999,7 @@ class X2goSessionRegistry(object):
 
         @param profile_name: session profile name
         @type profile_name: C{str}
-        @param return_objects: return as list of L{X2goSession} instances
+        @param return_objects: return as list of L{X2GoSession} instances
         @type return_objects: C{bool}
         @param return_session_names: return as list of X2Go session names
         @type return_session_names: C{bool}
@@ -1018,13 +1017,13 @@ class X2goSessionRegistry(object):
 
     def control_session_of_profile_name(self, profile_name):
         """\
-        For a given session profile name retrieve a the corresponding C{X2goControlSession*} instance.
+        For a given session profile name retrieve a the corresponding C{X2GoControlSession*} instance.
 
         @param profile_name: session profile name
         @type profile_name: C{str}
 
         @return: contol session instance
-        @rtype: C{X2goControlSession*} instance
+        @rtype: C{X2GoControlSession*} instance
 
         """
         _sessions = self.registered_sessions_of_profile_name(profile_name, return_objects=True)
@@ -1063,7 +1062,7 @@ class X2goSessionRegistry(object):
 
         @param profile_name: the profile name that we query the master session of
         @type profile_name: C{str}
-        @param return_object: return L{X2goSession} instance
+        @param return_object: return L{X2GoSession} instance
         @type return_object: C{bool}
         @param return_session_name: return X2Go session name
         @type return_session_name: C{bool}
