@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2013 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -47,12 +47,12 @@ def x2go_transport_tcp_handler(chan, (origin_addr, origin_port), (server_addr, s
 
     However, additionally this handler function checks the server port of the incoming channel
     and detects if there are Paramiko/SSH reverse forwarding tunnels waiting for the incoming 
-    channels. The Paramiko/SSH reverse forwarding tunnels are initiated by an L{X2goSession} instance
+    channels. The Paramiko/SSH reverse forwarding tunnels are initiated by an L{X2GoSession} instance
     (currently supported: reverse tunneling auf audio data, reverse tunneling of SSH requests).
 
-    If the server port of an incoming Paramiko/SSH channel matches the configured port of an L{X2goRevFwTunnel} 
-    instance, this instance gets notified of the incoming channel and a new L{X2goRevFwChannelThread} is 
-    started. This L{X2goRevFwChannelThread} then takes care of the new channel's incoming data stream.
+    If the server port of an incoming Paramiko/SSH channel matches the configured port of an L{X2GoRevFwTunnel} 
+    instance, this instance gets notified of the incoming channel and a new L{X2GoRevFwChannelThread} is 
+    started. This L{X2GoRevFwChannelThread} then takes care of the new channel's incoming data stream.
 
     """
     transport = chan.get_transport()
@@ -70,9 +70,9 @@ def x2go_transport_tcp_handler(chan, (origin_addr, origin_port), (server_addr, s
                 rev_tuns[session_name]['sshfs'][1].notify()
 
 
-class X2goRevFwTunnel(threading.Thread):
+class X2GoRevFwTunnel(threading.Thread):
     """\
-    L{X2goRevFwTunnel} class objects are used to reversely tunnel 
+    L{X2GoRevFwTunnel} class objects are used to reversely tunnel 
     X2Go audio, X2Go printing and X2Go folder sharing / device mounting
     through Paramiko/SSH.
 
@@ -81,10 +81,10 @@ class X2goRevFwTunnel(threading.Thread):
         """\
         Setup a reverse tunnel through Paramiko/SSH.
 
-        After the reverse tunnel has been setup up with L{X2goRevFwTunnel.start()} it waits
-        for notification from L{X2goRevFwTunnel.notify()} to accept incoming channels. This 
-        notification (L{X2goRevFwTunnel.notify()} gets called from within the transport's 
-        TCP handler function L{x2go_transport_tcp_handler} of the L{X2goSession} instance.
+        After the reverse tunnel has been setup up with L{X2GoRevFwTunnel.start()} it waits
+        for notification from L{X2GoRevFwTunnel.notify()} to accept incoming channels. This 
+        notification (L{X2GoRevFwTunnel.notify()} gets called from within the transport's 
+        TCP handler function L{x2go_transport_tcp_handler} of the L{X2GoSession} instance.
 
         @param server_port: the TCP/IP port on the X2Go server (starting point of the tunnel), 
             normally some number above 30000
@@ -95,18 +95,18 @@ class X2goRevFwTunnel(threading.Thread):
         @param remote_port: the TCP/IP port on the X2Go client (end point of the tunnel),
             normally an application's standard port (22 for SSH, 4713 for pulse audio, etc.)
         @type remote_port: int
-        @param ssh_transport: the L{X2goSession}'s Paramiko/SSH transport instance
+        @param ssh_transport: the L{X2GoSession}'s Paramiko/SSH transport instance
         @type ssh_transport: C{paramiko.Transport} instance
-        @param logger: you can pass an L{X2goLogger} object to the
-            L{X2goRevFwTunnel} constructor
-        @type logger: L{X2goLogger} instance
-        @param loglevel: if no L{X2goLogger} object has been supplied a new one will be
+        @param logger: you can pass an L{X2GoLogger} object to the
+            L{X2GoRevFwTunnel} constructor
+        @type logger: L{X2GoLogger} instance
+        @param loglevel: if no L{X2GoLogger} object has been supplied a new one will be
             constructed with the given loglevel
         @type loglevel: int
 
         """
         if logger is None:
-            self.logger = log.X2goLogger(loglevel=loglevel)
+            self.logger = log.X2GoLogger(loglevel=loglevel)
         else:
             self.logger = copy.deepcopy(logger)
         self.logger.tag = __NAME__
@@ -155,7 +155,7 @@ class X2goRevFwTunnel(threading.Thread):
     def pause(self):
         """\
         Prevent acceptance of new incoming connections through the Paramiko/SSH
-        reverse forwarding tunnel. Also, any active connection on this L{X2goRevFwTunnel}
+        reverse forwarding tunnel. Also, any active connection on this L{X2GoRevFwTunnel}
         instance will be closed immediately, if this method is called.
 
         """
@@ -177,14 +177,14 @@ class X2goRevFwTunnel(threading.Thread):
 
     def notify(self):
         """\
-        Notify an L{X2goRevFwTunnel} instance of an incoming Paramiko/SSH channel.
+        Notify an L{X2GoRevFwTunnel} instance of an incoming Paramiko/SSH channel.
 
         If an incoming reverse tunnel channel appropriate for this instance has
-        been detected, this method gets called from the L{X2goSession}'s transport
+        been detected, this method gets called from the L{X2GoSession}'s transport
         TCP handler.
 
         The sent notification will trigger a C{thread.Condition()} waiting for notification
-        in L{X2goRevFwTunnel.run()}.
+        in L{X2GoRevFwTunnel.run()}.
 
         """
         self.incoming_channel.acquire()
@@ -194,7 +194,7 @@ class X2goRevFwTunnel(threading.Thread):
 
     def stop_thread(self):
         """\
-        Stops this L{X2goRevFwTunnel} thread completely.
+        Stops this L{X2GoRevFwTunnel} thread completely.
 
         """
         self.pause()
@@ -220,23 +220,23 @@ class X2goRevFwTunnel(threading.Thread):
 
     def run(self):
         """\
-        This method gets run once an L{X2goRevFwTunnel} has been started with its
-        L{start()} method. Use L{X2goRevFwTunnel}.stop_thread() to stop the
+        This method gets run once an L{X2GoRevFwTunnel} has been started with its
+        L{start()} method. Use L{X2GoRevFwTunnel}.stop_thread() to stop the
         reverse forwarding tunnel again. You can also temporarily lock the tunnel
-        down with L{X2goRevFwTunnel.pause()} and L{X2goRevFwTunnel.resume()}).
+        down with L{X2GoRevFwTunnel.pause()} and L{X2GoRevFwTunnel.resume()}).
 
-        L{X2goRevFwTunnel.run()} waits for notifications of an appropriate incoming
-        Paramiko/SSH channel (issued by L{X2goRevFwTunnel.notify()}). Appropriate in
+        L{X2GoRevFwTunnel.run()} waits for notifications of an appropriate incoming
+        Paramiko/SSH channel (issued by L{X2GoRevFwTunnel.notify()}). Appropriate in
         this context means, that its start point on the X2Go server matches the class's
         property C{server_port}.
 
         Once a new incoming channel gets announced by the L{notify()} method, a new 
-        L{X2goRevFwChannelThread} instance will be initialized. As a data stream handler,
+        L{X2GoRevFwChannelThread} instance will be initialized. As a data stream handler,
         the function L{x2go_rev_forward_channel_handler()} will be used.
 
         The channel will last till the connection gets dropped on the X2Go server side or 
-        until the tunnel gets paused by an L{X2goRevFwTunnel.pause()} call or stopped via the
-        L{X2goRevFwTunnel.stop_thread()} method.
+        until the tunnel gets paused by an L{X2GoRevFwTunnel.pause()} call or stopped via the
+        L{X2GoRevFwTunnel.stop_thread()} method.
 
         """
         self._request_port_forwarding()
@@ -257,7 +257,7 @@ class X2goRevFwTunnel(threading.Thread):
 
             self.incoming_channel.release()
             if self._accept_channels and self._keepalive:
-                _new_chan_thread = X2goRevFwChannelThread(_chan, (self.remote_host, self.remote_port), 
+                _new_chan_thread = X2GoRevFwChannelThread(_chan, (self.remote_host, self.remote_port), 
                                                           target=x2go_rev_forward_channel_handler, 
                                                           kwargs={ 
                                                             'chan': _chan,
@@ -273,16 +273,16 @@ class X2goRevFwTunnel(threading.Thread):
 
 def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=None, logger=None, ):
     """\
-    Handle the data stream of a requested channel that got set up by a L{X2goRevFwTunnel} (Paramiko/SSH 
+    Handle the data stream of a requested channel that got set up by a L{X2GoRevFwTunnel} (Paramiko/SSH 
     reverse forwarding tunnel).
 
     The channel (and the corresponding connections) close either ...
 
         - ... if the connecting application closes the connection and thus, drops 
         the channel, or
-        - ... if the L{X2goRevFwTunnel} parent thread gets paused. The call
-        of L{X2goRevFwTunnel.pause()} on the instance can be used to shut down all incoming 
-        tunneled SSH connections associated to this L{X2goRevFwTunnel} instance
+        - ... if the L{X2GoRevFwTunnel} parent thread gets paused. The call
+        of L{X2GoRevFwTunnel.pause()} on the instance can be used to shut down all incoming 
+        tunneled SSH connections associated to this L{X2GoRevFwTunnel} instance
         from within a Python X2Go application.
 
     @param chan: channel
@@ -291,11 +291,11 @@ def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=N
     @type addr: C{str}
     @param port: bind port
     @type port: C{int}
-    @param parent_thread: the calling L{X2goRevFwTunnel} instance
-    @type parent_thread: L{X2goRevFwTunnel} instance
-    @param logger: you can pass an L{X2goLogger} object to the
-        L{X2goRevFwTunnel} constructor
-    @type logger: L{X2goLogger} instance
+    @param parent_thread: the calling L{X2GoRevFwTunnel} instance
+    @type parent_thread: L{X2GoRevFwTunnel} instance
+    @param logger: you can pass an L{X2GoLogger} object to the
+        L{X2GoRevFwTunnel} constructor
+    @type logger: L{X2GoLogger} instance
 
     """
     fw_socket = socket.socket()
@@ -332,7 +332,7 @@ def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=N
     logger('Reverse tunnel %s closed from %r' % (chan, chan.origin_addr,), loglevel=log.loglevel_INFO)
 
 
-class X2goRevFwChannelThread(threading.Thread):
+class X2GoRevFwChannelThread(threading.Thread):
     """\
     Starts a thread for each incoming Paramiko/SSH data channel trough the reverse
     forwarding tunnel.
@@ -342,7 +342,7 @@ class X2goRevFwChannelThread(threading.Thread):
         """\
         Initializes a reverse forwarding channel thread.
 
-        @param channel: incoming Paramiko/SSH channel from the L{X2goSession}'s transport
+        @param channel: incoming Paramiko/SSH channel from the L{X2GoSession}'s transport
             accept queue
         @type channel: class
         @param remote: tuple (addr, port) that specifies the data endpoint of the channel
